/*     */ package com.netapp.asup.cache.server;
/*     */ 
/*     */ import com.googlecode.concurrentlinkedhashmap.EvictionListener;
/*     */ import com.netapp.asup.common.AsupException;
/*     */ import com.netapp.asup.common.AsupLogger;
/*     */ import java.io.IOException;
/*     */ import java.net.InetSocketAddress;
/*     */ import java.util.Arrays;
/*     */ import java.util.Collection;
/*     */ import java.util.Map;
/*     */ import java.util.concurrent.Executors;
/*     */ import java.util.concurrent.ScheduledExecutorService;
/*     */ import java.util.concurrent.TimeUnit;
/*     */ import java.util.concurrent.TimeoutException;
/*     */ import net.rubyeye.xmemcached.MemcachedClient;
/*     */ import net.rubyeye.xmemcached.MemcachedClientBuilder;
/*     */ import net.rubyeye.xmemcached.MemcachedClientStateListener;
/*     */ import net.rubyeye.xmemcached.XMemcachedClientBuilder;
/*     */ import net.rubyeye.xmemcached.exception.MemcachedException;
/*     */ import net.rubyeye.xmemcached.impl.ElectionMemcachedSessionLocator;
/*     */ import net.rubyeye.xmemcached.impl.KetamaMemcachedSessionLocator;
/*     */ import net.rubyeye.xmemcached.utils.AddrUtil;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class AsupServerCacheImpl
/*     */   implements AsupGenericCache<String, Object>
/*     */ {
/*     */   private static final int DEFAULT_CACHE_EXPIRY = 2592000;
/*  31 */   private static final AsupLogger LOGGER = AsupLogger.getLogger(AsupServerCacheImpl.class);
/*     */   
/*     */   private static final String DEFAULT_ASUP_ID = "-9999";
/*     */   
/*     */   private MemcachedClient cacheClient;
/*     */   
/*     */   private AsupMemCacheStats cacheStats;
/*     */   
/*  39 */   private final ScheduledExecutorService statisticsThreadPool = Executors.newSingleThreadScheduledExecutor();
/*     */   
/*     */   public AsupServerCacheImpl(String connectionEndPoints) throws AsupException, IOException
/*     */   {
/*  43 */     this(connectionEndPoints, MemcachedHash.CONSISTENT);
/*     */   }
/*     */   
/*     */   public AsupServerCacheImpl(String connectionEndPoints, MemcachedHash hashType) throws AsupException, IOException
/*     */   {
/*  48 */     String[] connections = connectionEndPoints.split(",");
/*     */     
/*  50 */     for (String connection : connections) {
/*  51 */       String[] hostandport = connection.trim().split(":");
/*  52 */       if (hostandport.length != 2) {
/*  53 */         throw new AsupException(LOGGER, "-9999", "configured arma.rest.server.hostandportnames in invalid format:\" " + connectionEndPoints + " \",Correct format is: \"servername1:port1 servername2:port2\"");
/*     */       }
/*     */     }
/*     */     
/*     */ 
/*  58 */     connectionEndPoints = connectionEndPoints.replace(",", " ");
/*     */     
/*  60 */     if (LOGGER.isDebugEnabled()) {
/*  61 */       LOGGER.debug(null, "Memcache Connection URL : " + connectionEndPoints);
/*     */     }
/*  63 */     MemcachedClientBuilder builder = new XMemcachedClientBuilder(AddrUtil.getAddresses(connectionEndPoints));
/*     */     
/*  65 */     switch (hashType)
/*     */     {
/*     */     case STANDARD: 
/*     */       break;
/*     */     
/*     */ 
/*     */     case CONSISTENT: 
/*  72 */       builder.setSessionLocator(new KetamaMemcachedSessionLocator(true));
/*  73 */       break;
/*     */     
/*     */     case ELECTION: 
/*  76 */       builder.setSessionLocator(new ElectionMemcachedSessionLocator());
/*     */     }
/*     */     
/*     */     
/*  80 */     builder.addStateListener(new MemCacheStateListener());
/*     */     
/*  82 */     this.cacheClient = builder.build();
/*  83 */     this.cacheStats = new AsupMemCacheStats();
/*     */     
/*  85 */     this.statisticsThreadPool.scheduleAtFixedRate(new StatisticsRunnable(this), 0L, 300L, TimeUnit.SECONDS);
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*  90 */     System.setProperty("xmemcached.statistics.enable", "true");
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public String getCacheStats()
/*     */   {
/*  97 */     StringBuilder builder = new StringBuilder();
/*  98 */     builder.append("Memcache stats: ");
/*     */     
/* 100 */     builder.append(" total available servers : ");
/* 101 */     builder.append(this.cacheClient.getAvailableServers());
/* 102 */     builder.append(" server description : ");
/* 103 */     builder.append(this.cacheClient.getServersDescription());
/* 104 */     builder.append("\n");
/* 105 */     builder.append(this.cacheStats.toString());
/* 106 */     return builder.toString();
/*     */   }
/*     */   
/*     */   public void logStats()
/*     */   {
/* 111 */     if (LOGGER.isDebugEnabled()) {
/* 112 */       LOGGER.debug(null, "Statistics thread periodic log print of cache statistics : \n" + getCacheStats());
/*     */     }
/*     */   }
/*     */   
/*     */   public Object get(String key) {
/* 117 */     Object data = null;
/*     */     try
/*     */     {
/* 120 */       data = this.cacheClient.get(key);
/* 121 */       if (LOGGER.isDebugEnabled()) {
/* 122 */         LOGGER.debug(null, "Memcache get value on key : " + key + " is " + data);
/*     */       }
/*     */     } catch (Exception e) {
/* 125 */       LOGGER.warn(null, "Exception during get operation" + e.getMessage());
/*     */     }
/* 127 */     if (data == null) {
/* 128 */       this.cacheStats.miss();
/* 129 */       return data;
/*     */     }
/* 131 */     this.cacheStats.hit();
/* 132 */     return data;
/*     */   }
/*     */   
/*     */   public boolean touch(String key, int ttl)
/*     */   {
/*     */     try
/*     */     {
/* 139 */       return this.cacheClient.touch(key, ttl);
/*     */     } catch (Exception e) {
/* 141 */       LOGGER.warn(null, "Exception during touch operation in memcache:" + key, e);
/*     */     }
/* 143 */     return false;
/*     */   }
/*     */   
/*     */   public <T> T getAndTouch(String key, int ttl)
/*     */   {
/* 148 */     T data = null;
/*     */     try {
/* 150 */       data = this.cacheClient.getAndTouch(key, ttl);
/*     */     } catch (Exception e) {
/* 152 */       LOGGER.warn(null, "Touch and get failed : ", e);
/*     */     }
/* 154 */     if (data == null) {
/* 155 */       this.cacheStats.miss();
/* 156 */       return data;
/*     */     }
/* 158 */     this.cacheStats.hit();
/* 159 */     return data;
/*     */   }
/*     */   
/*     */   public void addServer(String connection)
/*     */     throws AsupException, IOException
/*     */   {
/* 165 */     if (connection.split(":").length != 2) {
/* 166 */       throw new AsupException(LOGGER, null, "Connection hostname:port is not a valid format:\" " + connection + " \",Correct format is: \"serverhostname:port ");
/*     */     }
/*     */     
/*     */ 
/*     */ 
/* 171 */     this.cacheClient.addServer(connection);
/* 172 */     LOGGER.info(null, "Adding the following memcache server connection:" + connection);
/*     */   }
/*     */   
/*     */   public void removeServer(String connection)
/*     */     throws AsupException, IOException
/*     */   {
/* 178 */     if (connection.split(":").length != 2) {
/* 179 */       throw new AsupException(LOGGER, null, "Configuration arma.rest.server.hostandportnames in invalid format:\" " + connection + " \",Correct format is: \"serverhostname:port ");
/*     */     }
/*     */     
/* 182 */     this.cacheClient.removeServer(connection);
/* 183 */     LOGGER.info(null, "Removed the following memcache server connection:" + connection);
/*     */   }
/*     */   
/*     */   public Object putIfAbsent(String key, Object value)
/*     */   {
/* 188 */     Object prevValue = null;
/*     */     try {
/* 190 */       prevValue = this.cacheClient.get(key);
/*     */       
/* 192 */       if (prevValue == null)
/*     */       {
/* 194 */         boolean isAdded = this.cacheClient.add(key, 2592000, value);
/*     */         
/* 196 */         if (isAdded) {
/* 197 */           this.cacheStats.access();
/*     */         }
/*     */       }
/*     */     } catch (Exception e) {
/* 201 */       LOGGER.warn(null, "Exception during a add/putIfAbsent into memcache:" + key + e);
/*     */     }
/* 203 */     return prevValue;
/*     */   }
/*     */   
/*     */   public Object putIfAbsent(String key, int expiry, Object value)
/*     */   {
/* 208 */     Object prevValue = null;
/*     */     try {
/* 210 */       prevValue = this.cacheClient.get(key);
/*     */       
/* 212 */       if (prevValue == null)
/*     */       {
/* 214 */         boolean isAdded = this.cacheClient.add(key, expiry, value);
/*     */         
/* 216 */         if (isAdded) {
/* 217 */           this.cacheStats.access();
/*     */         }
/*     */       }
/*     */     } catch (Exception e) {
/* 221 */       LOGGER.warn(null, "Exception during a add/putIfAbsent into memcache:" + key + e);
/*     */     }
/* 223 */     return prevValue;
/*     */   }
/*     */   
/*     */   public Object put(String key, int expiry, Object value) throws TimeoutException, InterruptedException, MemcachedException
/*     */   {
/* 228 */     Object prevValue = null;
/*     */     try {
/* 230 */       prevValue = this.cacheClient.get(key);
/* 231 */       this.cacheClient.set(key, expiry, value);
/* 232 */       this.cacheStats.access();
/* 233 */       if (LOGGER.isDebugEnabled())
/* 234 */         LOGGER.debug(null, "Memcache put operation with key: " + key + " value : " + value);
/*     */     } catch (Exception e) {
/* 236 */       LOGGER.warn(null, "Exception while adding data to memcache: " + key, e);
/*     */     }
/* 238 */     return prevValue;
/*     */   }
/*     */   
/*     */   public Object put(String key, Object value)
/*     */   {
/* 243 */     Object prevValue = null;
/*     */     try {
/* 245 */       prevValue = this.cacheClient.get(key);
/* 246 */       this.cacheClient.set(key, 2592000, value);
/* 247 */       this.cacheStats.access();
/* 248 */       if (LOGGER.isDebugEnabled())
/* 249 */         LOGGER.debug(null, "Memcache put operation with key: " + key + " value : " + value);
/*     */     } catch (Exception e) {
/* 251 */       LOGGER.warn(null, "Exception while adding data to memcache: " + key, e);
/*     */     }
/*     */     
/*     */ 
/* 255 */     return prevValue;
/*     */   }
/*     */   
/*     */   public Object remove(String key)
/*     */   {
/* 260 */     Object prevValue = null;
/*     */     try {
/* 262 */       prevValue = this.cacheClient.get(key);
/*     */       
/* 264 */       boolean isDeleted = this.cacheClient.delete(key);
/* 265 */       if (isDeleted)
/* 266 */         this.cacheStats.removed();
/*     */     } catch (Exception ex) {
/* 268 */       LOGGER.warn(null, "Exception while removing key from memcache : " + key, ex);
/*     */     }
/* 270 */     return prevValue;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public void shutdown()
/*     */   {
/*     */     try
/*     */     {
/* 280 */       this.cacheClient.shutdown();
/* 281 */       LOGGER.info(null, "memcache client shutdown operation executed..");
/*     */       
/* 283 */       if (this.statisticsThreadPool != null) {
/* 284 */         this.statisticsThreadPool.shutdown();
/*     */       }
/* 286 */       LOGGER.info(null, "statistics thread pool shutdown executed..");
/*     */     }
/*     */     catch (IOException e) {
/* 289 */       LOGGER.warn(null, "Error shutting down the memcache client : ", e);
/*     */     }
/*     */   }
/*     */   
/*     */   public Map<InetSocketAddress, Map<String, String>> getStats()
/*     */   {
/* 295 */     Map<InetSocketAddress, Map<String, String>> statsMap = null;
/*     */     try {
/* 297 */       statsMap = this.cacheClient.getStats();
/* 298 */       LOGGER.debug(null, "cache all stats : " + statsMap);
/*     */     } catch (Exception e) {
/* 300 */       LOGGER.warn(null, "Error getting memcache stats : ", e);
/*     */     }
/* 302 */     return statsMap;
/*     */   }
/*     */   
/*     */   public boolean replace(String key, int ttl, Object value)
/*     */   {
/*     */     try {
/* 308 */       this.cacheClient.replace(key, ttl, value);
/* 309 */       this.cacheStats.replace();
/*     */     } catch (Exception e) {
/* 311 */       LOGGER.warn(null, "Error replacing memcache value, ofr the key:" + key, e);
/*     */     }
/* 313 */     return false;
/*     */   }
/*     */   
/*     */   public <T> Map<String, T> getBulk(String... keys)
/*     */     throws TimeoutException, InterruptedException, MemcachedException
/*     */   {
/* 319 */     Map<String, T> keyMap = null;
/* 320 */     Collection<String> keyCollections = Arrays.asList(keys);
/* 321 */     keyMap = this.cacheClient.get(keyCollections);
/* 322 */     this.cacheStats.bulkGet();
/* 323 */     return keyMap;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public void clear()
/*     */   {
/*     */     try
/*     */     {
/* 332 */       this.cacheClient.flushAll();
/* 333 */       this.cacheStats.clear();
/*     */     } catch (Exception e) {
/* 335 */       LOGGER.warn(null, "Error clear/flushing the cache : ", e);
/*     */     }
/*     */   }
/*     */   
/*     */   class MemCacheStateListener implements MemcachedClientStateListener {
/*     */     MemCacheStateListener() {}
/*     */     
/* 342 */     public void onConnected(MemcachedClient memcachedClient, InetSocketAddress inetSocketAddress) { AsupServerCacheImpl.LOGGER.info(null, "Connected to:" + inetSocketAddress); }
/*     */     
/*     */     public void onDisconnected(MemcachedClient memcachedClient, InetSocketAddress inetSocketAddress)
/*     */     {
/* 346 */       AsupServerCacheImpl.LOGGER.info(null, "Disconnect from:" + inetSocketAddress);
/*     */     }
/*     */     
/*     */     public void onException(MemcachedClient memcachedClient, Throwable throwable)
/*     */     {
/* 351 */       AsupServerCacheImpl.LOGGER.warn(null, throwable.getStackTrace().toString(), throwable);
/*     */     }
/*     */     
/*     */     public void onShutDown(MemcachedClient memcachedClient) {
/* 355 */       AsupServerCacheImpl.LOGGER.info(null, "MemcachedClient has been shutdown");
/*     */     }
/*     */     
/*     */     public void onStarted(MemcachedClient memcachedClient) {
/* 359 */       AsupServerCacheImpl.LOGGER.info(null, "MemcachedClient has been started");
/*     */     }
/*     */   }
/*     */   
/*     */   static class StatisticsRunnable implements Runnable
/*     */   {
/*     */     AsupServerCacheImpl memCacheClient;
/*     */     
/*     */     StatisticsRunnable(AsupServerCacheImpl memCacheClient) {
/* 368 */       this.memCacheClient = memCacheClient;
/*     */     }
/*     */     
/*     */     public void run()
/*     */     {
/* 373 */       this.memCacheClient.logStats();
/*     */     }
/*     */   }
/*     */   
/*     */   public void addEvictionListener(EvictionListener<String, Object> listener)
/*     */   {
/* 379 */     throw new UnsupportedOperationException("add Eviction Listener functionality not supported on ARMA Server cache..");
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asup\cache\server\AsupServerCacheImpl.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */