/*     */ package com.netapp.asup.data.adapter;
/*     */ 
/*     */ import com.netapp.asup.adapter.Adapter;
/*     */ import com.netapp.asup.common.AsupLogger;
/*     */ import com.netapp.asup.data.exception.ARMARemoteCallException;
/*     */ import com.netapp.asup.data.exception.ARMASchemaOutOfSyncException;
/*     */ import com.netapp.asup.data.objects.AvroTransmissionObject;
/*     */ import com.netapp.asup.data.objects.Identifier;
/*     */ import com.netapp.asup.data.objects.Request;
/*     */ import com.netapp.asup.data.objects.Response;
/*     */ import com.netapp.asup.data.objects.SchemaData;
/*     */ import com.netapp.asup.data.schema.ClientSchemaHelper;
/*     */ import com.netapp.asup.data.util.HttpConnectionManager;
/*     */ import com.netapp.asup.data.util.HttpConnectionManager.HttpConnection;
/*     */ import com.netapp.asup.exception.ARMAConfigurationException;
/*     */ import com.netapp.asup.exception.ARMAException;
/*     */ import com.netapp.asup.exception.AdapterException;
/*     */ 
/*     */ 
/*     */ public class RESTAdapter
/*     */   implements Adapter
/*     */ {
/*     */   private final HttpConnectionManager manager;
/*     */   private ClientSchemaHelper schemaHelper;
/*  25 */   private static final AsupLogger logger = AsupLogger.getLogger(RESTAdapter.class);
/*     */   
/*     */   public RESTAdapter(ClientSchemaHelper schemaHelper) throws ARMAConfigurationException {
/*  28 */     this.manager = HttpConnectionManager.getInstance();
/*  29 */     this.schemaHelper = schemaHelper;
/*     */   }
/*     */   
/*     */   public Response getData(Request request) throws AdapterException
/*     */   {
/*  34 */     addSchemaDetails(request);
/*  35 */     Response response = Response.initialize(request.getId());
/*     */     try {
/*  37 */       return (Response)postRequest("arma/data", response, request);
/*     */     }
/*     */     catch (ARMASchemaOutOfSyncException e) {
/*     */       try {
/*  41 */         this.schemaHelper.reloadSchemas();
/*  42 */         addSchemaDetails(request);
/*  43 */         return (Response)postRequest("arma/data", response, request);
/*     */       } catch (ARMAException ae) {
/*  45 */         throw new AdapterException(logger, request.getId(), "Error in getting parent object data from server caused by : " + ae.getMessage(), ae);
/*     */       }
/*     */     }
/*     */     catch (ARMARemoteCallException e) {
/*  49 */       throw new AdapterException(logger, request.getId(), "Error in getting data from server caused by :" + e.getMessage(), e);
/*     */     }
/*     */   }
/*     */   
/*     */   private void addSchemaDetails(Request request) {
/*  54 */     String allSchemaCrc = this.schemaHelper.getAllSchemaCrc();
/*  55 */     SchemaData schemaData = SchemaData.getInstance(allSchemaCrc);
/*  56 */     request.setSchemaData(schemaData.getObject());
/*     */   }
/*     */   
/*     */   public Identifier getMetaData(Identifier identifier) throws AdapterException
/*     */   {
/*     */     try {
/*  62 */       return (Identifier)postRequest("arma/metadata", identifier, identifier);
/*     */     } catch (ARMARemoteCallException e) {
/*  64 */       throw new AdapterException(logger, identifier.getId(), "Error in getting meta data from server caused by :" + e.getMessage(), e);
/*     */     }
/*     */   }
/*     */   
/*     */   public <Y extends AvroTransmissionObject, X extends AvroTransmissionObject> Y postRequest(String url, Y response, X request) throws ARMARemoteCallException, ARMASchemaOutOfSyncException {
/*  69 */     HttpConnectionManager.HttpConnection connection = this.manager.getConnection(request.getId(), url, "POST");
/*  70 */     return connection.postRequest(response, request);
/*     */   }
/*     */   
/*     */   public Response getObjectData(Request request) throws AdapterException
/*     */   {
/*  75 */     addSchemaDetails(request);
/*     */     
/*  77 */     Response response = Response.initialize(request.getId());
/*     */     try {
/*  79 */       return (Response)postRequest("arma/objectdata", response, request);
/*     */     }
/*     */     catch (ARMASchemaOutOfSyncException e) {
/*     */       try {
/*  83 */         this.schemaHelper.reloadSchemas();
/*  84 */         addSchemaDetails(request);
/*  85 */         return (Response)postRequest("arma/objectdata", response, request);
/*     */       } catch (ARMAException ae) {
/*  87 */         throw new AdapterException(logger, request.getId(), "Error in getting parent object data from server caused by : " + ae.getMessage(), ae);
/*     */       }
/*     */     }
/*     */     catch (ARMARemoteCallException e) {
/*  91 */       throw new AdapterException(logger, request.getId(), "Error in getting object data from server caused by : " + e.getMessage(), e);
/*     */     }
/*     */   }
/*     */   
/*     */   public Response getParentObjectData(Request request)
/*     */     throws AdapterException
/*     */   {
/*  98 */     addSchemaDetails(request);
/*     */     
/* 100 */     Response response = Response.initialize(request.getId());
/*     */     try {
/* 102 */       return (Response)postRequest("arma/parentobjectdata", response, request);
/*     */     } catch (ARMASchemaOutOfSyncException e) {
/*     */       try {
/* 105 */         this.schemaHelper.reloadSchemas();
/* 106 */         addSchemaDetails(request);
/* 107 */         return (Response)postRequest("arma/parentobjectdata", response, request);
/*     */       } catch (ARMAException ae) {
/* 109 */         throw new AdapterException(logger, request.getId(), "Error in getting parent object data from server caused by : " + ae.getMessage(), ae);
/*     */       }
/*     */     }
/*     */     catch (ARMARemoteCallException e) {
/* 113 */       throw new AdapterException(logger, request.getId(), "Error in getting parent object data from server caused by : " + e.getMessage(), e);
/*     */     }
/*     */   }
/*     */   
/*     */   public Response getOptionData(Request request) throws AdapterException
/*     */   {
/* 119 */     return getObjectData(request);
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asup\data\adapter\RESTAdapter.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */