/*     */ package com.sun.xml.bind.v2.util;
/*     */ 
/*     */ import com.sun.xml.bind.v2.runtime.Name;
/*     */ import java.util.AbstractSet;
/*     */ import java.util.Collection;
/*     */ import java.util.HashSet;
/*     */ import java.util.Iterator;
/*     */ import java.util.NoSuchElementException;
/*     */ import java.util.Set;
/*     */ import javax.xml.namespace.QName;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class QNameMap<V>
/*     */ {
/*     */   private static final int DEFAULT_INITIAL_CAPACITY = 16;
/*     */   private static final int MAXIMUM_CAPACITY = 1073741824;
/*  39 */   transient Entry<V>[] table = new Entry[16];
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   transient int size;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private int threshold;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private static final float DEFAULT_LOAD_FACTOR = 0.75F;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  63 */   private Set<Entry<V>> entrySet = null;
/*     */   
/*     */   public QNameMap() {
/*  66 */     this.threshold = 12;
/*  67 */     this.table = new Entry[16];
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void put(String namespaceUri, String localname, V value)
/*     */   {
/*  83 */     assert (localname != null);
/*  84 */     assert (namespaceUri != null);
/*     */     
/*  86 */     assert (localname == localname.intern());
/*  87 */     assert (namespaceUri == namespaceUri.intern());
/*     */     
/*  89 */     int hash = hash(localname);
/*  90 */     int i = indexFor(hash, this.table.length);
/*     */     
/*  92 */     for (Entry<V> e = this.table[i]; e != null; e = e.next) {
/*  93 */       if ((e.hash == hash) && (localname == e.localName) && (namespaceUri == e.nsUri)) {
/*  94 */         e.value = value;
/*  95 */         return;
/*     */       }
/*     */     }
/*     */     
/*  99 */     addEntry(hash, namespaceUri, localname, value, i);
/*     */   }
/*     */   
/*     */   public void put(QName name, V value)
/*     */   {
/* 104 */     put(name.getNamespaceURI(), name.getLocalPart(), value);
/*     */   }
/*     */   
/*     */   public void put(Name name, V value) {
/* 108 */     put(name.nsUri, name.localName, value);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public V get(String nsUri, String localPart)
/*     */   {
/* 122 */     Entry<V> e = getEntry(nsUri, localPart);
/* 123 */     if (e == null) return null;
/* 124 */     return (V)e.value;
/*     */   }
/*     */   
/*     */   public V get(QName name) {
/* 128 */     return (V)get(name.getNamespaceURI(), name.getLocalPart());
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public int size()
/*     */   {
/* 137 */     return this.size;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public QNameMap<V> putAll(QNameMap<? extends V> map)
/*     */   {
/* 149 */     int numKeysToBeAdded = map.size();
/* 150 */     if (numKeysToBeAdded == 0) {
/* 151 */       return this;
/*     */     }
/*     */     
/* 154 */     if (numKeysToBeAdded > this.threshold) {
/* 155 */       int targetCapacity = numKeysToBeAdded;
/* 156 */       if (targetCapacity > 1073741824)
/* 157 */         targetCapacity = 1073741824;
/* 158 */       int newCapacity = this.table.length;
/* 159 */       while (newCapacity < targetCapacity)
/* 160 */         newCapacity <<= 1;
/* 161 */       if (newCapacity > this.table.length) {
/* 162 */         resize(newCapacity);
/*     */       }
/*     */     }
/* 165 */     for (Entry<? extends V> e : map.entrySet())
/* 166 */       put(e.nsUri, e.localName, e.getValue());
/* 167 */     return this;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private static int hash(String x)
/*     */   {
/* 176 */     int h = x.hashCode();
/*     */     
/* 178 */     h += (h << 9 ^ 0xFFFFFFFF);
/* 179 */     h ^= h >>> 14;
/* 180 */     h += (h << 4);
/* 181 */     h ^= h >>> 10;
/* 182 */     return h;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   private static int indexFor(int h, int length)
/*     */   {
/* 189 */     return h & length - 1;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private void addEntry(int hash, String nsUri, String localName, V value, int bucketIndex)
/*     */   {
/* 199 */     Entry<V> e = this.table[bucketIndex];
/* 200 */     this.table[bucketIndex] = new Entry(hash, nsUri, localName, value, e);
/* 201 */     if (this.size++ >= this.threshold) {
/* 202 */       resize(2 * this.table.length);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private void resize(int newCapacity)
/*     */   {
/* 212 */     Entry[] oldTable = this.table;
/* 213 */     int oldCapacity = oldTable.length;
/* 214 */     if (oldCapacity == 1073741824) {
/* 215 */       this.threshold = Integer.MAX_VALUE;
/* 216 */       return;
/*     */     }
/*     */     
/* 219 */     Entry[] newTable = new Entry[newCapacity];
/* 220 */     transfer(newTable);
/* 221 */     this.table = newTable;
/* 222 */     this.threshold = newCapacity;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   private void transfer(Entry<V>[] newTable)
/*     */   {
/* 229 */     Entry<V>[] src = this.table;
/* 230 */     int newCapacity = newTable.length;
/* 231 */     for (int j = 0; j < src.length; j++) {
/* 232 */       Entry<V> e = src[j];
/* 233 */       if (e != null) {
/* 234 */         src[j] = null;
/*     */         do {
/* 236 */           Entry<V> next = e.next;
/* 237 */           int i = indexFor(e.hash, newCapacity);
/* 238 */           e.next = newTable[i];
/* 239 */           newTable[i] = e;
/* 240 */           e = next;
/* 241 */         } while (e != null);
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public Entry<V> getOne()
/*     */   {
/* 254 */     for (Entry<V> e : this.table) {
/* 255 */       if (e != null)
/* 256 */         return e;
/*     */     }
/* 258 */     return null;
/*     */   }
/*     */   
/*     */   public Collection<QName> keySet() {
/* 262 */     Set<QName> r = new HashSet();
/* 263 */     for (Entry<V> e : entrySet()) {
/* 264 */       r.add(e.createQName());
/*     */     }
/* 266 */     return r;
/*     */   }
/*     */   
/*     */   private abstract class HashIterator<E> implements Iterator<E> {
/*     */     QNameMap.Entry<V> next;
/*     */     int index;
/*     */     
/*     */     HashIterator() {
/* 274 */       QNameMap.Entry<V>[] t = QNameMap.this.table;
/* 275 */       int i = t.length;
/* 276 */       QNameMap.Entry<V> n = null;
/* 277 */       while ((QNameMap.this.size != 0) && 
/* 278 */         (i > 0) && ((n = t[(--i)]) == null)) {}
/*     */       
/*     */ 
/* 281 */       this.next = n;
/* 282 */       this.index = i;
/*     */     }
/*     */     
/*     */     public boolean hasNext() {
/* 286 */       return this.next != null;
/*     */     }
/*     */     
/*     */     QNameMap.Entry<V> nextEntry() {
/* 290 */       QNameMap.Entry<V> e = this.next;
/* 291 */       if (e == null) {
/* 292 */         throw new NoSuchElementException();
/*     */       }
/* 294 */       QNameMap.Entry<V> n = e.next;
/* 295 */       QNameMap.Entry<V>[] t = QNameMap.this.table;
/* 296 */       int i = this.index;
/* 297 */       while ((n == null) && (i > 0))
/* 298 */         n = t[(--i)];
/* 299 */       this.index = i;
/* 300 */       this.next = n;
/* 301 */       return e;
/*     */     }
/*     */     
/*     */     public void remove() {
/* 305 */       throw new UnsupportedOperationException();
/*     */     }
/*     */   }
/*     */   
/*     */   public boolean containsKey(String nsUri, String localName) {
/* 310 */     return getEntry(nsUri, localName) != null;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public boolean isEmpty()
/*     */   {
/* 318 */     return this.size == 0;
/*     */   }
/*     */   
/*     */ 
/*     */   public static final class Entry<V>
/*     */   {
/*     */     public final String nsUri;
/*     */     
/*     */     public final String localName;
/*     */     
/*     */     V value;
/*     */     
/*     */     final int hash;
/*     */     
/*     */     Entry<V> next;
/*     */     
/*     */ 
/*     */     Entry(int h, String nsUri, String localName, V v, Entry<V> n)
/*     */     {
/* 337 */       this.value = v;
/* 338 */       this.next = n;
/* 339 */       this.nsUri = nsUri;
/* 340 */       this.localName = localName;
/* 341 */       this.hash = h;
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */     public QName createQName()
/*     */     {
/* 348 */       return new QName(this.nsUri, this.localName);
/*     */     }
/*     */     
/*     */     public V getValue() {
/* 352 */       return (V)this.value;
/*     */     }
/*     */     
/*     */     public V setValue(V newValue) {
/* 356 */       V oldValue = this.value;
/* 357 */       this.value = newValue;
/* 358 */       return oldValue;
/*     */     }
/*     */     
/*     */     public boolean equals(Object o) {
/* 362 */       if (!(o instanceof Entry))
/* 363 */         return false;
/* 364 */       Entry e = (Entry)o;
/* 365 */       String k1 = this.nsUri;
/* 366 */       String k2 = e.nsUri;
/* 367 */       String k3 = this.localName;
/* 368 */       String k4 = e.localName;
/* 369 */       if ((k1 == k2) || ((k1 != null) && (k1.equals(k2)) && ((k3 == k4) || ((k3 != null) && (k3.equals(k4))))))
/*     */       {
/* 371 */         Object v1 = getValue();
/* 372 */         Object v2 = e.getValue();
/* 373 */         if ((v1 == v2) || ((v1 != null) && (v1.equals(v2))))
/* 374 */           return true;
/*     */       }
/* 376 */       return false;
/*     */     }
/*     */     
/*     */     public int hashCode() {
/* 380 */       return this.localName.hashCode() ^ (this.value == null ? 0 : this.value.hashCode());
/*     */     }
/*     */     
/*     */     public String toString()
/*     */     {
/* 385 */       return '"' + this.nsUri + "\",\"" + this.localName + "\"=" + getValue();
/*     */     }
/*     */   }
/*     */   
/*     */   public Set<Entry<V>> entrySet() {
/* 390 */     Set<Entry<V>> es = this.entrySet;
/* 391 */     return es != null ? es : (this.entrySet = new EntrySet(null));
/*     */   }
/*     */   
/*     */ 
/* 395 */   private Iterator<Entry<V>> newEntryIterator() { return new EntryIterator(null); }
/*     */   
/*     */   private class EntryIterator extends QNameMap<V>.HashIterator<QNameMap.Entry<V>> {
/* 398 */     private EntryIterator() { super(); }
/*     */     
/* 400 */     public QNameMap.Entry<V> next() { return nextEntry(); }
/*     */   }
/*     */   
/*     */   private class EntrySet extends AbstractSet<QNameMap.Entry<V>> { private EntrySet() {}
/*     */     
/* 405 */     public Iterator<QNameMap.Entry<V>> iterator() { return QNameMap.this.newEntryIterator(); }
/*     */     
/*     */     public boolean contains(Object o) {
/* 408 */       if (!(o instanceof QNameMap.Entry))
/* 409 */         return false;
/* 410 */       QNameMap.Entry<V> e = (QNameMap.Entry)o;
/* 411 */       QNameMap.Entry<V> candidate = QNameMap.this.getEntry(e.nsUri, e.localName);
/* 412 */       return (candidate != null) && (candidate.equals(e));
/*     */     }
/*     */     
/* 415 */     public boolean remove(Object o) { throw new UnsupportedOperationException(); }
/*     */     
/*     */     public int size() {
/* 418 */       return QNameMap.this.size;
/*     */     }
/*     */   }
/*     */   
/*     */   private Entry<V> getEntry(String nsUri, String localName)
/*     */   {
/* 424 */     assert (nsUri == nsUri.intern());
/* 425 */     assert (localName == localName.intern());
/*     */     
/* 427 */     int hash = hash(localName);
/* 428 */     int i = indexFor(hash, this.table.length);
/* 429 */     Entry<V> e = this.table[i];
/* 430 */     while ((e != null) && ((localName != e.localName) || (nsUri != e.nsUri)))
/* 431 */       e = e.next;
/* 432 */     return e;
/*     */   }
/*     */   
/*     */   public String toString() {
/* 436 */     StringBuilder buf = new StringBuilder();
/* 437 */     buf.append('{');
/*     */     
/* 439 */     for (Entry<V> e : entrySet()) {
/* 440 */       if (buf.length() > 1)
/* 441 */         buf.append(',');
/* 442 */       buf.append('[');
/* 443 */       buf.append(e);
/* 444 */       buf.append(']');
/*     */     }
/*     */     
/* 447 */     buf.append('}');
/* 448 */     return buf.toString();
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\target\myautosupport\WEB-INF\lib\jaxb-impl-2.0.3.jar!\com\sun\xml\bind\v2\util\QNameMap.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */