/*     */ package net.rubyeye.xmemcached.command;
/*     */ 
/*     */ import com.google.code.yanf4j.buffer.IoBuffer;
/*     */ import java.net.InetSocketAddress;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collection;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import java.util.concurrent.CountDownLatch;
/*     */ import net.rubyeye.xmemcached.CommandFactory;
/*     */ import net.rubyeye.xmemcached.buffer.BufferAllocator;
/*     */ import net.rubyeye.xmemcached.buffer.SimpleBufferAllocator;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryAppendPrependCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryAuthListMechanismsCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryAuthStartCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryAuthStepCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryCASCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryDeleteCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryFlushAllCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryGetAndTouchCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryGetCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryGetMultiCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryIncrDecrCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryQuitCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryStatsCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryStoreCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryTouchCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryVerbosityCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryVersionCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.OpCode;
/*     */ import net.rubyeye.xmemcached.transcoders.Transcoder;
/*     */ import net.rubyeye.xmemcached.utils.ByteUtils;
/*     */ import net.rubyeye.xmemcached.utils.Protocol;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class BinaryCommandFactory
/*     */   implements CommandFactory
/*     */ {
/*  46 */   private BufferAllocator bufferAllocator = new SimpleBufferAllocator();
/*     */   
/*     */   public void setBufferAllocator(BufferAllocator bufferAllocator) {
/*  49 */     this.bufferAllocator = bufferAllocator;
/*     */   }
/*     */   
/*     */   public Command createAddCommand(String key, byte[] keyBytes, int exp, Object value, boolean noreply, Transcoder transcoder)
/*     */   {
/*  54 */     return createStoreCommand(key, keyBytes, exp, value, CommandType.ADD, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createAppendCommand(String key, byte[] keyBytes, Object value, boolean noreply, Transcoder transcoder)
/*     */   {
/*  60 */     return new BinaryAppendPrependCommand(key, keyBytes, CommandType.APPEND, new CountDownLatch(1), 0, 0L, value, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public Command createCASCommand(String key, byte[] keyBytes, int exp, Object value, long cas, boolean noreply, Transcoder transcoder)
/*     */   {
/*  67 */     return new BinaryCASCommand(key, keyBytes, CommandType.CAS, new CountDownLatch(1), exp, cas, value, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createDeleteCommand(String key, byte[] keyBytes, int time, boolean noreply)
/*     */   {
/*  73 */     return new BinaryDeleteCommand(key, keyBytes, CommandType.DELETE, new CountDownLatch(1), noreply);
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createFlushAllCommand(CountDownLatch latch, int delay, boolean noreply)
/*     */   {
/*  79 */     return new BinaryFlushAllCommand(latch, delay, noreply);
/*     */   }
/*     */   
/*     */   public Command createGetCommand(String key, byte[] keyBytes, CommandType cmdType, Transcoder transcoder)
/*     */   {
/*  84 */     return new BinaryGetCommand(key, keyBytes, cmdType, new CountDownLatch(1), OpCode.GET, false);
/*     */   }
/*     */   
/*     */ 
/*     */   public <T> Command createGetMultiCommand(Collection<String> keys, CountDownLatch latch, CommandType cmdType, Transcoder<T> transcoder)
/*     */   {
/*  90 */     Iterator<String> it = keys.iterator();
/*  91 */     String key = null;
/*  92 */     List<IoBuffer> bufferList = new ArrayList();
/*  93 */     int totalLength = 0;
/*  94 */     while (it.hasNext()) {
/*  95 */       key = (String)it.next();
/*  96 */       if (it.hasNext())
/*     */       {
/*  98 */         Command command = new BinaryGetCommand(key, ByteUtils.getBytes(key), cmdType, null, OpCode.GET_KEY_QUIETLY, true);
/*     */         
/*     */ 
/* 101 */         command.encode();
/* 102 */         totalLength += command.getIoBuffer().remaining();
/* 103 */         bufferList.add(command.getIoBuffer());
/*     */       }
/*     */     }
/*     */     
/* 107 */     Command lastCommand = new BinaryGetCommand(key, ByteUtils.getBytes(key), cmdType, new CountDownLatch(1), OpCode.GET_KEY, false);
/*     */     
/*     */ 
/* 110 */     lastCommand.encode();
/* 111 */     bufferList.add(lastCommand.getIoBuffer());
/* 112 */     totalLength += lastCommand.getIoBuffer().remaining();
/*     */     
/* 114 */     IoBuffer mergedBuffer = IoBuffer.allocate(totalLength);
/* 115 */     for (IoBuffer buffer : bufferList) {
/* 116 */       mergedBuffer.put(buffer.buf());
/*     */     }
/* 118 */     mergedBuffer.flip();
/* 119 */     Command resultCommand = new BinaryGetMultiCommand(key, cmdType, latch);
/* 120 */     resultCommand.setIoBuffer(mergedBuffer);
/* 121 */     return resultCommand;
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createIncrDecrCommand(String key, byte[] keyBytes, long amount, long initial, int expTime, CommandType cmdType, boolean noreply)
/*     */   {
/* 127 */     return new BinaryIncrDecrCommand(key, keyBytes, amount, initial, expTime, cmdType, noreply);
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createPrependCommand(String key, byte[] keyBytes, Object value, boolean noreply, Transcoder transcoder)
/*     */   {
/* 133 */     return new BinaryAppendPrependCommand(key, keyBytes, CommandType.PREPEND, new CountDownLatch(1), 0, 0L, value, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public Command createReplaceCommand(String key, byte[] keyBytes, int exp, Object value, boolean noreply, Transcoder transcoder)
/*     */   {
/* 140 */     return createStoreCommand(key, keyBytes, exp, value, CommandType.REPLACE, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   final Command createStoreCommand(String key, byte[] keyBytes, int exp, Object value, CommandType cmdType, boolean noreply, Transcoder transcoder)
/*     */   {
/* 147 */     return new BinaryStoreCommand(key, keyBytes, cmdType, new CountDownLatch(1), exp, -1L, value, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createSetCommand(String key, byte[] keyBytes, int exp, Object value, boolean noreply, Transcoder transcoder)
/*     */   {
/* 153 */     return createStoreCommand(key, keyBytes, exp, value, CommandType.SET, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createStatsCommand(InetSocketAddress server, CountDownLatch latch, String itemName)
/*     */   {
/* 159 */     return new BinaryStatsCommand(server, latch, itemName);
/*     */   }
/*     */   
/*     */   public Command createVerbosityCommand(CountDownLatch latch, int level, boolean noreply)
/*     */   {
/* 164 */     return new BinaryVerbosityCommand(latch, level, noreply);
/*     */   }
/*     */   
/*     */   public Command createVersionCommand(CountDownLatch latch, InetSocketAddress server)
/*     */   {
/* 169 */     return new BinaryVersionCommand(latch, server);
/*     */   }
/*     */   
/*     */   public Command createAuthListMechanismsCommand(CountDownLatch latch) {
/* 173 */     return new BinaryAuthListMechanismsCommand(latch);
/*     */   }
/*     */   
/*     */   public Command createAuthStartCommand(String mechanism, CountDownLatch latch, byte[] authData)
/*     */   {
/* 178 */     return new BinaryAuthStartCommand(mechanism, ByteUtils.getBytes(mechanism), latch, authData);
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createAuthStepCommand(String mechanism, CountDownLatch latch, byte[] authData)
/*     */   {
/* 184 */     return new BinaryAuthStepCommand(mechanism, ByteUtils.getBytes(mechanism), latch, authData);
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createGetAndTouchCommand(String key, byte[] keyBytes, CountDownLatch latch, int exp, boolean noreply)
/*     */   {
/* 190 */     return new BinaryGetAndTouchCommand(key, keyBytes, noreply ? CommandType.GATQ : CommandType.GAT, latch, exp, noreply);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public Command createTouchCommand(String key, byte[] keyBytes, CountDownLatch latch, int exp, boolean noreply)
/*     */   {
/* 197 */     return new BinaryTouchCommand(key, keyBytes, CommandType.TOUCH, latch, exp, noreply);
/*     */   }
/*     */   
/*     */   public Command createQuitCommand()
/*     */   {
/* 202 */     return new BinaryQuitCommand();
/*     */   }
/*     */   
/*     */   public Protocol getProtocol() {
/* 206 */     return Protocol.Binary;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\net\rubyeye\xmemcached\command\BinaryCommandFactory.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */