/*     */ package net.rubyeye.xmemcached.impl;
/*     */ 
/*     */ import com.google.code.yanf4j.core.Session;
/*     */ import com.google.code.yanf4j.core.impl.AbstractSession;
/*     */ import com.google.code.yanf4j.core.impl.HandlerAdapter;
/*     */ import com.google.code.yanf4j.util.SystemUtils;
/*     */ import java.net.InetSocketAddress;
/*     */ import java.util.Collection;
/*     */ import java.util.Map;
/*     */ import java.util.concurrent.CountDownLatch;
/*     */ import java.util.concurrent.ExecutorService;
/*     */ import java.util.concurrent.Executors;
/*     */ import java.util.concurrent.TimeUnit;
/*     */ import java.util.concurrent.atomic.AtomicInteger;
/*     */ import net.rubyeye.xmemcached.MemcachedClient;
/*     */ import net.rubyeye.xmemcached.MemcachedClientStateListener;
/*     */ import net.rubyeye.xmemcached.auth.AuthMemcachedConnectListener;
/*     */ import net.rubyeye.xmemcached.command.Command;
/*     */ import net.rubyeye.xmemcached.command.CommandType;
/*     */ import net.rubyeye.xmemcached.command.MapReturnValueAware;
/*     */ import net.rubyeye.xmemcached.command.OperationStatus;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryGetCommand;
/*     */ import net.rubyeye.xmemcached.command.binary.BinaryVersionCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextGetOneCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextVersionCommand;
/*     */ import net.rubyeye.xmemcached.monitor.StatisticsHandler;
/*     */ import net.rubyeye.xmemcached.networking.Connector;
/*     */ import net.rubyeye.xmemcached.networking.MemcachedSession;
/*     */ import net.rubyeye.xmemcached.networking.MemcachedSessionConnectListener;
/*     */ import net.rubyeye.xmemcached.utils.InetSocketAddressWrapper;
/*     */ import net.rubyeye.xmemcached.utils.Protocol;
/*     */ import org.slf4j.Logger;
/*     */ import org.slf4j.LoggerFactory;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class MemcachedHandler
/*     */   extends HandlerAdapter
/*     */ {
/*     */   private final StatisticsHandler statisticsHandler;
/*     */   private ExecutorService heartBeatThreadPool;
/*     */   private final MemcachedSessionConnectListener listener;
/*     */   private final MemcachedClient client;
/*  64 */   private static final Logger log = LoggerFactory.getLogger(MemcachedHandler.class);
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final void onMessageReceived(Session session, Object msg)
/*     */   {
/*  72 */     Command command = (Command)msg;
/*  73 */     if (this.statisticsHandler.isStatistics()) {
/*  74 */       if (command.getMergeCount() > 0) {
/*  75 */         int size = ((MapReturnValueAware)command).getReturnValues().size();
/*     */         
/*  77 */         this.statisticsHandler.statistics(CommandType.GET_HIT, size);
/*  78 */         this.statisticsHandler.statistics(CommandType.GET_MISS, command.getMergeCount() - size);
/*     */       }
/*  80 */       else if (((command instanceof TextGetOneCommand)) || ((command instanceof BinaryGetCommand)))
/*     */       {
/*  82 */         if (command.getResult() != null) {
/*  83 */           this.statisticsHandler.statistics(CommandType.GET_HIT);
/*     */         } else {
/*  85 */           this.statisticsHandler.statistics(CommandType.GET_MISS);
/*     */         }
/*     */       } else {
/*  88 */         this.statisticsHandler.statistics(command.getCommandType());
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*  93 */   private volatile boolean enableHeartBeat = true;
/*     */   private static final String HEART_BEAT_FAIL_COUNT_ATTR = "heartBeatFailCount";
/*     */   
/*  96 */   public void setEnableHeartBeat(boolean enableHeartBeat) { this.enableHeartBeat = enableHeartBeat; }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final void onMessageSent(Session session, Object msg)
/*     */   {
/* 104 */     Command command = (Command)msg;
/* 105 */     command.setStatus(OperationStatus.SENT);
/* 106 */     if ((!command.isNoreply()) || (this.client.getProtocol() == Protocol.Binary))
/*     */     {
/* 108 */       ((MemcachedTCPSession)session).addCommand(command);
/*     */     }
/*     */   }
/*     */   
/*     */   public void onExceptionCaught(Session session, Throwable throwable)
/*     */   {
/* 114 */     log.error("XMemcached network layout exception", throwable);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public void onSessionStarted(Session session)
/*     */   {
/* 122 */     session.setUseBlockingRead(true);
/* 123 */     session.setAttribute("heartBeatFailCount", new AtomicInteger(0));
/* 124 */     for (MemcachedClientStateListener listener : this.client.getStateListeners())
/*     */     {
/* 126 */       listener.onConnected(this.client, session.getRemoteSocketAddress());
/*     */     }
/* 128 */     this.listener.onConnect((MemcachedTCPSession)session, this.client);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public final void onSessionClosed(Session session)
/*     */   {
/* 136 */     this.client.getConnector().removeSession(session);
/*     */     
/* 138 */     ((AbstractSession)session).clearWriteQueue();
/* 139 */     MemcachedTCPSession memcachedSession = (MemcachedTCPSession)session;
/*     */     
/* 141 */     memcachedSession.destroy();
/* 142 */     if ((this.client.getConnector().isStarted()) && (memcachedSession.isAllowReconnect()))
/*     */     {
/* 144 */       reconnect(memcachedSession);
/*     */     }
/* 146 */     for (MemcachedClientStateListener listener : this.client.getStateListeners())
/*     */     {
/* 148 */       listener.onDisconnected(this.client, session.getRemoteSocketAddress());
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void onSessionIdle(Session session)
/*     */   {
/* 159 */     checkHeartBeat(session);
/*     */   }
/*     */   
/*     */   private void checkHeartBeat(Session session) {
/* 163 */     log.debug("Check session (%s) is alive,send heartbeat", SystemUtils.getRawAddress(session.getRemoteSocketAddress()) + ":" + session.getRemoteSocketAddress().getPort());
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 170 */     Command versionCommand = null;
/* 171 */     CountDownLatch latch = new CountDownLatch(1);
/* 172 */     if (this.client.getProtocol() == Protocol.Binary) {
/* 173 */       versionCommand = new BinaryVersionCommand(latch, session.getRemoteSocketAddress());
/*     */     }
/*     */     else
/*     */     {
/* 177 */       versionCommand = new TextVersionCommand(latch, session.getRemoteSocketAddress());
/*     */     }
/*     */     
/* 180 */     session.write(versionCommand);
/*     */     
/* 182 */     if (this.heartBeatThreadPool != null) {
/* 183 */       this.heartBeatThreadPool.execute(new CheckHeartResultThread(versionCommand, session));
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/* 190 */   private static final int MAX_HEART_BEAT_FAIL_COUNT = Integer.parseInt(System.getProperty("xmemcached.heartbeat.max.fail.times", "3"));
/*     */   
/*     */ 
/*     */   static final class CheckHeartResultThread
/*     */     implements Runnable
/*     */   {
/*     */     private final Command versionCommand;
/*     */     private final Session session;
/*     */     
/*     */     public CheckHeartResultThread(Command versionCommand, Session session)
/*     */     {
/* 201 */       this.versionCommand = versionCommand;
/* 202 */       this.session = session;
/*     */     }
/*     */     
/*     */     public void run() {
/*     */       try {
/* 207 */         AtomicInteger heartBeatFailCount = (AtomicInteger)this.session.getAttribute("heartBeatFailCount");
/*     */         
/* 209 */         if (heartBeatFailCount != null) {
/* 210 */           if (!this.versionCommand.getLatch().await(2000L, TimeUnit.MILLISECONDS))
/*     */           {
/* 212 */             heartBeatFailCount.incrementAndGet();
/*     */           }
/* 214 */           if (this.versionCommand.getResult() == null) {
/* 215 */             heartBeatFailCount.incrementAndGet();
/*     */           }
/*     */           else {
/* 218 */             heartBeatFailCount.set(0);
/*     */           }
/* 220 */           if (heartBeatFailCount.get() > MemcachedHandler.MAX_HEART_BEAT_FAIL_COUNT) {
/* 221 */             MemcachedHandler.log.warn("Session(" + SystemUtils.getRawAddress(this.session.getRemoteSocketAddress()) + ":" + this.session.getRemoteSocketAddress().getPort() + ") heartbeat fail " + heartBeatFailCount.get() + " times,close session and try to heal it");
/*     */             
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 229 */             this.session.close();
/* 230 */             heartBeatFailCount.set(0);
/*     */           }
/*     */         }
/*     */       }
/*     */       catch (InterruptedException e) {}
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected void reconnect(MemcachedTCPSession session)
/*     */   {
/* 245 */     if (!this.client.isShutdown())
/*     */     {
/* 247 */       synchronized (session) {
/* 248 */         if (!session.isAllowReconnect()) {
/* 249 */           return;
/*     */         }
/* 251 */         session.setAllowReconnect(false);
/*     */       }
/* 253 */       MemcachedSession memcachedTCPSession = session;
/* 254 */       InetSocketAddressWrapper inetSocketAddressWrapper = memcachedTCPSession.getInetSocketAddressWrapper();
/*     */       
/* 256 */       this.client.getConnector().addToWatingQueue(new ReconnectRequest(inetSocketAddressWrapper, 0, this.client.getHealSessionInterval()));
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */   public void stop()
/*     */   {
/* 263 */     this.heartBeatThreadPool.shutdown();
/*     */   }
/*     */   
/* 266 */   final long HEARTBEAT_PERIOD = Long.parseLong(System.getProperty("xmemcached.heartbeat.period", "5000"));
/*     */   
/*     */   public void start()
/*     */   {
/* 270 */     int serverSize = this.client.getAvaliableServers().size();
/* 271 */     this.heartBeatThreadPool = Executors.newFixedThreadPool(serverSize == 0 ? Runtime.getRuntime().availableProcessors() : serverSize);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public MemcachedHandler(MemcachedClient client)
/*     */   {
/* 278 */     this.client = client;
/* 279 */     this.listener = new AuthMemcachedConnectListener();
/* 280 */     this.statisticsHandler = new StatisticsHandler();
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\net\rubyeye\xmemcached\impl\MemcachedHandler.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */