/*     */ package org.apache.avro.generic;
/*     */ 
/*     */ import java.nio.ByteBuffer;
/*     */ import java.util.AbstractList;
/*     */ import java.util.Arrays;
/*     */ import java.util.Collection;
/*     */ import java.util.HashMap;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import java.util.Map.Entry;
/*     */ import org.apache.avro.AvroRuntimeException;
/*     */ import org.apache.avro.AvroTypeException;
/*     */ import org.apache.avro.Schema;
/*     */ import org.apache.avro.Schema.Field;
/*     */ import org.apache.avro.Schema.Field.Order;
/*     */ import org.apache.avro.Schema.Type;
/*     */ import org.apache.avro.UnresolvedUnionException;
/*     */ import org.apache.avro.io.BinaryData;
/*     */ import org.apache.avro.io.DatumReader;
/*     */ import org.apache.avro.util.Utf8;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class GenericData
/*     */ {
/*  42 */   private static final GenericData INSTANCE = new GenericData();
/*     */   protected static final String STRING_PROP = "avro.java.string";
/*     */   
/*  45 */   public static enum StringType { CharSequence,  String,  Utf8;
/*     */     
/*     */ 
/*     */ 
/*     */     private StringType() {}
/*     */   }
/*     */   
/*     */ 
/*     */   public static void setStringType(Schema s, StringType stringType)
/*     */   {
/*  55 */     if (stringType == StringType.String)
/*  56 */       s.addProp("avro.java.string", "String");
/*     */   }
/*     */   
/*     */   public static GenericData get() {
/*  60 */     return INSTANCE;
/*     */   }
/*     */   
/*     */   public static class Record implements GenericRecord, Comparable<Record>
/*     */   {
/*     */     private final Schema schema;
/*     */     private final Object[] values;
/*     */     
/*     */     public Record(Schema schema) {
/*  69 */       if ((schema == null) || (!Schema.Type.RECORD.equals(schema.getType())))
/*  70 */         throw new AvroRuntimeException("Not a record schema: " + schema);
/*  71 */       this.schema = schema;
/*  72 */       this.values = new Object[schema.getFields().size()];
/*     */     }
/*     */     
/*  75 */     public Record(Record other, boolean deepCopy) { this.schema = other.schema;
/*  76 */       this.values = new Object[this.schema.getFields().size()];
/*  77 */       if (deepCopy) {
/*  78 */         for (int ii = 0; ii < this.values.length; ii++) {
/*  79 */           this.values[ii] = GenericData.INSTANCE.deepCopy(((Schema.Field)this.schema.getFields().get(ii)).schema(), other.values[ii]);
/*     */         }
/*     */         
/*     */       }
/*     */       else
/*  84 */         System.arraycopy(other.values, 0, this.values, 0, other.values.length);
/*     */     }
/*     */     
/*  87 */     public Schema getSchema() { return this.schema; }
/*     */     
/*  89 */     public void put(String key, Object value) { Schema.Field field = this.schema.getField(key);
/*  90 */       if (field == null) {
/*  91 */         throw new AvroRuntimeException("Not a valid schema field: " + key);
/*     */       }
/*  93 */       this.values[field.pos()] = value; }
/*     */     
/*  95 */     public void put(int i, Object v) { this.values[i] = v; }
/*     */     
/*  97 */     public Object get(String key) { Schema.Field field = this.schema.getField(key);
/*  98 */       if (field == null) return null;
/*  99 */       return this.values[field.pos()]; }
/*     */     
/* 101 */     public Object get(int i) { return this.values[i]; }
/*     */     
/* 103 */     public boolean equals(Object o) { if (o == this) return true;
/* 104 */       if (!(o instanceof Record)) return false;
/* 105 */       Record that = (Record)o;
/* 106 */       if (!this.schema.equals(that.schema))
/* 107 */         return false;
/* 108 */       return GenericData.get().compare(this, that, this.schema, true) == 0;
/*     */     }
/*     */     
/* 111 */     public int hashCode() { return GenericData.get().hashCode(this, this.schema); }
/*     */     
/*     */     public int compareTo(Record that) {
/* 114 */       return GenericData.get().compare(this, that, this.schema);
/*     */     }
/*     */     
/* 117 */     public String toString() { return GenericData.get().toString(this); }
/*     */   }
/*     */   
/*     */ 
/*     */   public static class Array<T>
/*     */     extends AbstractList<T>
/*     */     implements GenericArray<T>, Comparable<GenericArray<T>>
/*     */   {
/* 125 */     private static final Object[] EMPTY = new Object[0];
/*     */     private final Schema schema;
/*     */     private int size;
/* 128 */     private Object[] elements = EMPTY;
/*     */     
/* 130 */     public Array(int capacity, Schema schema) { if ((schema == null) || (!Schema.Type.ARRAY.equals(schema.getType())))
/* 131 */         throw new AvroRuntimeException("Not an array schema: " + schema);
/* 132 */       this.schema = schema;
/* 133 */       if (capacity != 0)
/* 134 */         this.elements = new Object[capacity];
/*     */     }
/*     */     
/* 137 */     public Array(Schema schema, Collection<T> c) { if ((schema == null) || (!Schema.Type.ARRAY.equals(schema.getType())))
/* 138 */         throw new AvroRuntimeException("Not an array schema: " + schema);
/* 139 */       this.schema = schema;
/* 140 */       if (c != null) {
/* 141 */         this.elements = new Object[c.size()];
/* 142 */         addAll(c);
/*     */       } }
/*     */     
/* 145 */     public Schema getSchema() { return this.schema; }
/* 146 */     public int size() { return this.size; }
/* 147 */     public void clear() { this.size = 0; }
/*     */     
/* 149 */     public Iterator<T> iterator() { new Iterator() {
/* 150 */         private int position = 0;
/* 151 */         public boolean hasNext() { return this.position < GenericData.Array.this.size; }
/* 152 */         public T next() { return (T)GenericData.Array.this.elements[(this.position++)]; }
/* 153 */         public void remove() { throw new UnsupportedOperationException(); }
/*     */       }; }
/*     */     
/*     */     public T get(int i) {
/* 157 */       if (i >= this.size)
/* 158 */         throw new IndexOutOfBoundsException("Index " + i + " out of bounds.");
/* 159 */       return (T)this.elements[i];
/*     */     }
/*     */     
/* 162 */     public boolean add(T o) { if (this.size == this.elements.length) {
/* 163 */         Object[] newElements = new Object[this.size * 3 / 2 + 1];
/* 164 */         System.arraycopy(this.elements, 0, newElements, 0, this.size);
/* 165 */         this.elements = newElements;
/*     */       }
/* 167 */       this.elements[(this.size++)] = o;
/* 168 */       return true;
/*     */     }
/*     */     
/* 171 */     public void add(int location, T o) { if ((location > this.size) || (location < 0)) {
/* 172 */         throw new IndexOutOfBoundsException("Index " + location + " out of bounds.");
/*     */       }
/* 174 */       if (this.size == this.elements.length) {
/* 175 */         Object[] newElements = new Object[this.size * 3 / 2 + 1];
/* 176 */         System.arraycopy(this.elements, 0, newElements, 0, this.size);
/* 177 */         this.elements = newElements;
/*     */       }
/* 179 */       System.arraycopy(this.elements, location, this.elements, location + 1, this.size - location);
/* 180 */       this.elements[location] = o;
/* 181 */       this.size += 1;
/*     */     }
/*     */     
/* 184 */     public T set(int i, T o) { if (i >= this.size)
/* 185 */         throw new IndexOutOfBoundsException("Index " + i + " out of bounds.");
/* 186 */       T response = this.elements[i];
/* 187 */       this.elements[i] = o;
/* 188 */       return response;
/*     */     }
/*     */     
/* 191 */     public T remove(int i) { if (i >= this.size)
/* 192 */         throw new IndexOutOfBoundsException("Index " + i + " out of bounds.");
/* 193 */       T result = this.elements[i];
/* 194 */       this.size -= 1;
/* 195 */       System.arraycopy(this.elements, i + 1, this.elements, i, this.size - i);
/* 196 */       this.elements[this.size] = null;
/* 197 */       return result;
/*     */     }
/*     */     
/* 200 */     public T peek() { return (T)(this.size < this.elements.length ? this.elements[this.size] : null); }
/*     */     
/*     */ 
/* 203 */     public int compareTo(GenericArray<T> that) { return GenericData.get().compare(this, that, getSchema()); }
/*     */     
/*     */     public void reverse() {
/* 206 */       int left = 0;
/* 207 */       int right = this.elements.length - 1;
/*     */       
/* 209 */       while (left < right) {
/* 210 */         Object tmp = this.elements[left];
/* 211 */         this.elements[left] = this.elements[right];
/* 212 */         this.elements[right] = tmp;
/*     */         
/* 214 */         left++;
/* 215 */         right--;
/*     */       }
/*     */     }
/*     */     
/*     */     public String toString() {
/* 220 */       StringBuffer buffer = new StringBuffer();
/* 221 */       buffer.append("[");
/* 222 */       int count = 0;
/* 223 */       for (T e : this) {
/* 224 */         buffer.append(e == null ? "null" : e.toString());
/* 225 */         count++; if (count < size())
/* 226 */           buffer.append(", ");
/*     */       }
/* 228 */       buffer.append("]");
/* 229 */       return buffer.toString();
/*     */     }
/*     */   }
/*     */   
/*     */   public static class Fixed
/*     */     implements GenericFixed, Comparable<Fixed> {
/*     */     private Schema schema;
/*     */     private byte[] bytes;
/*     */     
/* 238 */     public Fixed(Schema schema) { setSchema(schema); }
/*     */     
/*     */     public Fixed(Schema schema, byte[] bytes) {
/* 241 */       this.schema = schema;
/* 242 */       this.bytes = bytes;
/*     */     }
/*     */     
/*     */     protected Fixed() {}
/*     */     
/*     */     protected void setSchema(Schema schema) {
/* 248 */       this.schema = schema;
/* 249 */       this.bytes = new byte[schema.getFixedSize()];
/*     */     }
/*     */     
/* 252 */     public Schema getSchema() { return this.schema; }
/*     */     
/* 254 */     public void bytes(byte[] bytes) { this.bytes = bytes; }
/*     */     
/* 256 */     public byte[] bytes() { return this.bytes; }
/*     */     
/*     */     public boolean equals(Object o)
/*     */     {
/* 260 */       if (o == this) return true;
/* 261 */       return ((o instanceof GenericFixed)) && (Arrays.equals(this.bytes, ((GenericFixed)o).bytes()));
/*     */     }
/*     */     
/*     */     public int hashCode()
/*     */     {
/* 266 */       return Arrays.hashCode(this.bytes);
/*     */     }
/*     */     
/* 269 */     public String toString() { return Arrays.toString(this.bytes); }
/*     */     
/*     */     public int compareTo(Fixed that) {
/* 272 */       return BinaryData.compareBytes(this.bytes, 0, this.bytes.length, that.bytes, 0, that.bytes.length);
/*     */     }
/*     */   }
/*     */   
/*     */   public static class EnumSymbol implements GenericEnumSymbol
/*     */   {
/*     */     private Schema schema;
/*     */     private String symbol;
/*     */     
/*     */     public EnumSymbol(Schema schema, String symbol)
/*     */     {
/* 283 */       this.schema = schema;
/* 284 */       this.symbol = symbol;
/*     */     }
/*     */     
/* 287 */     public Schema getSchema() { return this.schema; }
/*     */     
/*     */     public boolean equals(Object o)
/*     */     {
/* 291 */       if (o == this) return true;
/* 292 */       return ((o instanceof GenericEnumSymbol)) && (this.symbol.equals(o.toString()));
/*     */     }
/*     */     
/*     */     public int hashCode()
/*     */     {
/* 297 */       return this.symbol.hashCode();
/*     */     }
/*     */     
/* 300 */     public String toString() { return this.symbol; }
/*     */   }
/*     */   
/*     */   public DatumReader createDatumReader(Schema schema)
/*     */   {
/* 305 */     return new GenericDatumReader(schema, schema, this);
/*     */   }
/*     */   
/*     */   public boolean validate(Schema schema, Object datum)
/*     */   {
/* 310 */     switch (schema.getType()) {
/*     */     case RECORD: 
/* 312 */       if (!isRecord(datum)) return false;
/* 313 */       for (Schema.Field f : schema.getFields()) {
/* 314 */         if (!validate(f.schema(), getField(datum, f.name(), f.pos())))
/* 315 */           return false;
/*     */       }
/* 317 */       return true;
/*     */     case ENUM: 
/* 319 */       return schema.getEnumSymbols().contains(datum.toString());
/*     */     case ARRAY: 
/* 321 */       if (!(datum instanceof Collection)) return false;
/* 322 */       for (Object element : (Collection)datum)
/* 323 */         if (!validate(schema.getElementType(), element))
/* 324 */           return false;
/* 325 */       return true;
/*     */     case MAP: 
/* 327 */       if (!(datum instanceof Map)) { return false;
/*     */       }
/* 329 */       Map<Object, Object> map = (Map)datum;
/* 330 */       for (Map.Entry<Object, Object> entry : map.entrySet())
/* 331 */         if (!validate(schema.getValueType(), entry.getValue()))
/* 332 */           return false;
/* 333 */       return true;
/*     */     case UNION: 
/* 335 */       for (Schema type : schema.getTypes())
/* 336 */         if (validate(type, datum))
/* 337 */           return true;
/* 338 */       return false;
/*     */     case FIXED: 
/* 340 */       return ((datum instanceof GenericFixed)) && (((GenericFixed)datum).bytes().length == schema.getFixedSize());
/*     */     case STRING: 
/* 342 */       return isString(datum);
/* 343 */     case BYTES:  return isBytes(datum);
/* 344 */     case INT:  return datum instanceof Integer;
/* 345 */     case LONG:  return datum instanceof Long;
/* 346 */     case FLOAT:  return datum instanceof Float;
/* 347 */     case DOUBLE:  return datum instanceof Double;
/* 348 */     case BOOLEAN:  return datum instanceof Boolean;
/* 349 */     case NULL:  return datum == null; }
/* 350 */     return false;
/*     */   }
/*     */   
/*     */ 
/*     */   public String toString(Object datum)
/*     */   {
/* 356 */     StringBuilder buffer = new StringBuilder();
/* 357 */     toString(datum, buffer);
/* 358 */     return buffer.toString();
/*     */   }
/*     */   
/*     */   protected void toString(Object datum, StringBuilder buffer) {
/* 362 */     if (isRecord(datum)) {
/* 363 */       buffer.append("{");
/* 364 */       int count = 0;
/* 365 */       Schema schema = getRecordSchema(datum);
/* 366 */       for (Schema.Field f : schema.getFields()) {
/* 367 */         toString(f.name(), buffer);
/* 368 */         buffer.append(": ");
/* 369 */         toString(getField(datum, f.name(), f.pos()), buffer);
/* 370 */         count++; if (count < schema.getFields().size())
/* 371 */           buffer.append(", ");
/*     */       }
/* 373 */       buffer.append("}");
/* 374 */     } else if ((datum instanceof Collection)) {
/* 375 */       Collection<?> array = (Collection)datum;
/* 376 */       buffer.append("[");
/* 377 */       long last = array.size() - 1;
/* 378 */       int i = 0;
/* 379 */       for (Object element : array) {
/* 380 */         toString(element, buffer);
/* 381 */         if (i++ < last)
/* 382 */           buffer.append(", ");
/*     */       }
/* 384 */       buffer.append("]");
/* 385 */     } else if ((datum instanceof Map)) {
/* 386 */       buffer.append("{");
/* 387 */       int count = 0;
/*     */       
/* 389 */       Map<Object, Object> map = (Map)datum;
/* 390 */       for (Map.Entry<Object, Object> entry : map.entrySet()) {
/* 391 */         toString(entry.getKey(), buffer);
/* 392 */         buffer.append(": ");
/* 393 */         toString(entry.getValue(), buffer);
/* 394 */         count++; if (count < map.size())
/* 395 */           buffer.append(", ");
/*     */       }
/* 397 */       buffer.append("}");
/* 398 */     } else if (((datum instanceof CharSequence)) || ((datum instanceof GenericEnumSymbol)))
/*     */     {
/* 400 */       buffer.append("\"");
/* 401 */       writeEscapedString(datum.toString(), buffer);
/* 402 */       buffer.append("\"");
/* 403 */     } else if ((datum instanceof ByteBuffer)) {
/* 404 */       buffer.append("{\"bytes\": \"");
/* 405 */       ByteBuffer bytes = (ByteBuffer)datum;
/* 406 */       for (int i = bytes.position(); i < bytes.limit(); i++)
/* 407 */         buffer.append((char)bytes.get(i));
/* 408 */       buffer.append("\"}");
/*     */     } else {
/* 410 */       buffer.append(datum);
/*     */     }
/*     */   }
/*     */   
/*     */   private void writeEscapedString(String string, StringBuilder builder)
/*     */   {
/* 416 */     for (int i = 0; i < string.length(); i++) {
/* 417 */       char ch = string.charAt(i);
/* 418 */       switch (ch) {
/*     */       case '"': 
/* 420 */         builder.append("\\\"");
/* 421 */         break;
/*     */       case '\\': 
/* 423 */         builder.append("\\\\");
/* 424 */         break;
/*     */       case '\b': 
/* 426 */         builder.append("\\b");
/* 427 */         break;
/*     */       case '\f': 
/* 429 */         builder.append("\\f");
/* 430 */         break;
/*     */       case '\n': 
/* 432 */         builder.append("\\n");
/* 433 */         break;
/*     */       case '\r': 
/* 435 */         builder.append("\\r");
/* 436 */         break;
/*     */       case '\t': 
/* 438 */         builder.append("\\t");
/* 439 */         break;
/*     */       case '/': 
/* 441 */         builder.append("\\/");
/* 442 */         break;
/*     */       
/*     */       default: 
/* 445 */         if (((ch >= 0) && (ch <= '\037')) || ((ch >= '') && (ch <= '')) || ((ch >= ' ') && (ch <= '⃿'))) {
/* 446 */           String hex = Integer.toHexString(ch);
/* 447 */           builder.append("\\u");
/* 448 */           for (int j = 0; j < 4 - builder.length(); j++)
/* 449 */             builder.append('0');
/* 450 */           builder.append(string.toUpperCase());
/*     */         } else {
/* 452 */           builder.append(ch);
/*     */         }
/*     */         break;
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */   public Schema induce(Object datum) {
/* 460 */     if (isRecord(datum))
/* 461 */       return getRecordSchema(datum);
/* 462 */     if ((datum instanceof Collection)) {
/* 463 */       Schema elementType = null;
/* 464 */       for (Object element : (Collection)datum) {
/* 465 */         if (elementType == null) {
/* 466 */           elementType = induce(element);
/* 467 */         } else if (!elementType.equals(induce(element))) {
/* 468 */           throw new AvroTypeException("No mixed type arrays.");
/*     */         }
/*     */       }
/* 471 */       if (elementType == null) {
/* 472 */         throw new AvroTypeException("Empty array: " + datum);
/*     */       }
/* 474 */       return Schema.createArray(elementType);
/*     */     }
/* 476 */     if ((datum instanceof Map))
/*     */     {
/* 478 */       Map<Object, Object> map = (Map)datum;
/* 479 */       Schema value = null;
/* 480 */       for (Map.Entry<Object, Object> entry : map.entrySet()) {
/* 481 */         if (value == null) {
/* 482 */           value = induce(entry.getValue());
/* 483 */         } else if (!value.equals(induce(entry.getValue()))) {
/* 484 */           throw new AvroTypeException("No mixed type map values.");
/*     */         }
/*     */       }
/* 487 */       if (value == null) {
/* 488 */         throw new AvroTypeException("Empty map: " + datum);
/*     */       }
/* 490 */       return Schema.createMap(value); }
/* 491 */     if ((datum instanceof GenericFixed)) {
/* 492 */       return Schema.createFixed(null, null, null, ((GenericFixed)datum).bytes().length);
/*     */     }
/*     */     
/* 495 */     if ((datum instanceof CharSequence)) return Schema.create(Schema.Type.STRING);
/* 496 */     if ((datum instanceof ByteBuffer)) return Schema.create(Schema.Type.BYTES);
/* 497 */     if ((datum instanceof Integer)) return Schema.create(Schema.Type.INT);
/* 498 */     if ((datum instanceof Long)) return Schema.create(Schema.Type.LONG);
/* 499 */     if ((datum instanceof Float)) return Schema.create(Schema.Type.FLOAT);
/* 500 */     if ((datum instanceof Double)) return Schema.create(Schema.Type.DOUBLE);
/* 501 */     if ((datum instanceof Boolean)) return Schema.create(Schema.Type.BOOLEAN);
/* 502 */     if (datum == null) { return Schema.create(Schema.Type.NULL);
/*     */     }
/* 504 */     throw new AvroTypeException("Can't create schema for: " + datum);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public void setField(Object record, String name, int position, Object o)
/*     */   {
/* 511 */     ((IndexedRecord)record).put(position, o);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public Object getField(Object record, String name, int position)
/*     */   {
/* 518 */     return ((IndexedRecord)record).get(position);
/*     */   }
/*     */   
/*     */ 
/*     */   protected Object getRecordState(Object record, Schema schema)
/*     */   {
/* 524 */     return null;
/*     */   }
/*     */   
/*     */   protected void setField(Object r, String n, int p, Object o, Object state) {
/* 528 */     setField(r, n, p, o);
/*     */   }
/*     */   
/*     */   protected Object getField(Object record, String name, int pos, Object state)
/*     */   {
/* 533 */     return getField(record, name, pos);
/*     */   }
/*     */   
/*     */ 
/*     */   public int resolveUnion(Schema union, Object datum)
/*     */   {
/* 539 */     Integer i = union.getIndexNamed(getSchemaName(datum));
/* 540 */     if (i != null)
/* 541 */       return i.intValue();
/* 542 */     throw new UnresolvedUnionException(union, datum);
/*     */   }
/*     */   
/*     */ 
/*     */   protected String getSchemaName(Object datum)
/*     */   {
/* 548 */     if (datum == null)
/* 549 */       return Schema.Type.NULL.getName();
/* 550 */     if (isRecord(datum))
/* 551 */       return getRecordSchema(datum).getFullName();
/* 552 */     if (isEnum(datum))
/* 553 */       return getEnumSchema(datum).getFullName();
/* 554 */     if (isArray(datum))
/* 555 */       return Schema.Type.ARRAY.getName();
/* 556 */     if (isMap(datum))
/* 557 */       return Schema.Type.MAP.getName();
/* 558 */     if (isFixed(datum))
/* 559 */       return getFixedSchema(datum).getFullName();
/* 560 */     if (isString(datum))
/* 561 */       return Schema.Type.STRING.getName();
/* 562 */     if (isBytes(datum))
/* 563 */       return Schema.Type.BYTES.getName();
/* 564 */     if ((datum instanceof Integer))
/* 565 */       return Schema.Type.INT.getName();
/* 566 */     if ((datum instanceof Long))
/* 567 */       return Schema.Type.LONG.getName();
/* 568 */     if ((datum instanceof Float))
/* 569 */       return Schema.Type.FLOAT.getName();
/* 570 */     if ((datum instanceof Double))
/* 571 */       return Schema.Type.DOUBLE.getName();
/* 572 */     if ((datum instanceof Boolean))
/* 573 */       return Schema.Type.BOOLEAN.getName();
/* 574 */     throw new AvroRuntimeException("Unknown datum type: " + datum);
/*     */   }
/*     */   
/*     */ 
/*     */   protected boolean instanceOf(Schema schema, Object datum)
/*     */   {
/* 580 */     switch (schema.getType()) {
/*     */     case RECORD: 
/* 582 */       if (!isRecord(datum)) return false;
/* 583 */       return schema.getFullName() == null ? false : getRecordSchema(datum).getFullName() == null ? true : schema.getFullName().equals(getRecordSchema(datum).getFullName());
/*     */     
/*     */ 
/*     */     case ENUM: 
/* 587 */       if (!isEnum(datum)) return false;
/* 588 */       return schema.getFullName().equals(getEnumSchema(datum).getFullName());
/* 589 */     case ARRAY:  return isArray(datum);
/* 590 */     case MAP:  return isMap(datum);
/*     */     case FIXED: 
/* 592 */       if (!isFixed(datum)) return false;
/* 593 */       return schema.getFullName().equals(getFixedSchema(datum).getFullName());
/* 594 */     case STRING:  return isString(datum);
/* 595 */     case BYTES:  return isBytes(datum);
/* 596 */     case INT:  return datum instanceof Integer;
/* 597 */     case LONG:  return datum instanceof Long;
/* 598 */     case FLOAT:  return datum instanceof Float;
/* 599 */     case DOUBLE:  return datum instanceof Double;
/* 600 */     case BOOLEAN:  return datum instanceof Boolean;
/* 601 */     case NULL:  return datum == null; }
/* 602 */     throw new AvroRuntimeException("Unexpected type: " + schema);
/*     */   }
/*     */   
/*     */ 
/*     */   protected boolean isArray(Object datum)
/*     */   {
/* 608 */     return datum instanceof Collection;
/*     */   }
/*     */   
/*     */   protected boolean isRecord(Object datum)
/*     */   {
/* 613 */     return datum instanceof IndexedRecord;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   protected Schema getRecordSchema(Object record)
/*     */   {
/* 620 */     return ((GenericContainer)record).getSchema();
/*     */   }
/*     */   
/*     */   protected boolean isEnum(Object datum)
/*     */   {
/* 625 */     return datum instanceof GenericEnumSymbol;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   protected Schema getEnumSchema(Object enu)
/*     */   {
/* 632 */     return ((GenericContainer)enu).getSchema();
/*     */   }
/*     */   
/*     */   protected boolean isMap(Object datum)
/*     */   {
/* 637 */     return datum instanceof Map;
/*     */   }
/*     */   
/*     */   protected boolean isFixed(Object datum)
/*     */   {
/* 642 */     return datum instanceof GenericFixed;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   protected Schema getFixedSchema(Object fixed)
/*     */   {
/* 649 */     return ((GenericContainer)fixed).getSchema();
/*     */   }
/*     */   
/*     */   protected boolean isString(Object datum)
/*     */   {
/* 654 */     return datum instanceof CharSequence;
/*     */   }
/*     */   
/*     */   protected boolean isBytes(Object datum)
/*     */   {
/* 659 */     return datum instanceof ByteBuffer;
/*     */   }
/*     */   
/*     */ 
/*     */   public int hashCode(Object o, Schema s)
/*     */   {
/* 665 */     if (o == null) return 0;
/* 666 */     int hashCode = 1;
/* 667 */     switch (s.getType()) {
/*     */     case RECORD: 
/* 669 */       for (Schema.Field f : s.getFields()) {
/* 670 */         if (f.order() != Schema.Field.Order.IGNORE)
/*     */         {
/* 672 */           hashCode = hashCodeAdd(hashCode, getField(o, f.name(), f.pos()), f.schema());
/*     */         }
/*     */       }
/* 675 */       return hashCode;
/*     */     case ARRAY: 
/* 677 */       Collection<?> a = (Collection)o;
/* 678 */       Schema elementType = s.getElementType();
/* 679 */       for (Object e : a)
/* 680 */         hashCode = hashCodeAdd(hashCode, e, elementType);
/* 681 */       return hashCode;
/*     */     case UNION: 
/* 683 */       return hashCode(o, (Schema)s.getTypes().get(resolveUnion(s, o)));
/*     */     case ENUM: 
/* 685 */       return s.getEnumOrdinal(o.toString());
/*     */     case NULL: 
/* 687 */       return 0;
/*     */     case STRING: 
/* 689 */       return ((o instanceof Utf8) ? o : new Utf8(o.toString())).hashCode();
/*     */     }
/* 691 */     return o.hashCode();
/*     */   }
/*     */   
/*     */ 
/*     */   protected int hashCodeAdd(int hashCode, Object o, Schema s)
/*     */   {
/* 697 */     return 31 * hashCode + hashCode(o, s);
/*     */   }
/*     */   
/*     */ 
/*     */   protected static final String STRING_TYPE_STRING = "String";
/*     */   
/*     */   public int compare(Object o1, Object o2, Schema s)
/*     */   {
/* 705 */     return compare(o1, o2, s, false);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   protected int compare(Object o1, Object o2, Schema s, boolean equals)
/*     */   {
/* 712 */     if (o1 == o2) return 0;
/* 713 */     switch (s.getType()) {
/*     */     case RECORD: 
/* 715 */       for (Schema.Field f : s.getFields())
/* 716 */         if (f.order() != Schema.Field.Order.IGNORE)
/*     */         {
/* 718 */           int pos = f.pos();
/* 719 */           String name = f.name();
/* 720 */           int compare = compare(getField(o1, name, pos), getField(o2, name, pos), f.schema(), equals);
/*     */           
/*     */ 
/* 723 */           if (compare != 0)
/* 724 */             return f.order() == Schema.Field.Order.DESCENDING ? -compare : compare;
/*     */         }
/* 726 */       return 0;
/*     */     case ENUM: 
/* 728 */       return s.getEnumOrdinal(o1.toString()) - s.getEnumOrdinal(o2.toString());
/*     */     case ARRAY: 
/* 730 */       Collection a1 = (Collection)o1;
/* 731 */       Collection a2 = (Collection)o2;
/* 732 */       Iterator e1 = a1.iterator();
/* 733 */       Iterator e2 = a2.iterator();
/* 734 */       Schema elementType = s.getElementType();
/* 735 */       while ((e1.hasNext()) && (e2.hasNext())) {
/* 736 */         int compare = compare(e1.next(), e2.next(), elementType, equals);
/* 737 */         if (compare != 0) return compare;
/*     */       }
/* 739 */       return e2.hasNext() ? -1 : e1.hasNext() ? 1 : 0;
/*     */     case MAP: 
/* 741 */       if (equals)
/* 742 */         return ((Map)o1).equals(o2) ? 0 : 1;
/* 743 */       throw new AvroRuntimeException("Can't compare maps!");
/*     */     case UNION: 
/* 745 */       int i1 = resolveUnion(s, o1);
/* 746 */       int i2 = resolveUnion(s, o2);
/* 747 */       return i1 == i2 ? compare(o1, o2, (Schema)s.getTypes().get(i1), equals) : i1 - i2;
/*     */     
/*     */ 
/*     */     case NULL: 
/* 751 */       return 0;
/*     */     case STRING: 
/* 753 */       Utf8 u1 = (o1 instanceof Utf8) ? (Utf8)o1 : new Utf8(o1.toString());
/* 754 */       Utf8 u2 = (o2 instanceof Utf8) ? (Utf8)o2 : new Utf8(o2.toString());
/* 755 */       return u1.compareTo(u2);
/*     */     }
/* 757 */     return ((Comparable)o1).compareTo(o2);
/*     */   }
/*     */   
/*     */ 
/* 761 */   private static final Schema STRINGS = Schema.create(Schema.Type.STRING);
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public Object deepCopy(Schema schema, Object value)
/*     */   {
/* 771 */     if (value == null) {
/* 772 */       return null;
/*     */     }
/* 774 */     switch (schema.getType()) {
/*     */     case ARRAY: 
/* 776 */       List<Object> arrayValue = (List)value;
/* 777 */       List<Object> arrayCopy = new Array(arrayValue.size(), schema);
/*     */       
/* 779 */       for (Object obj : arrayValue) {
/* 780 */         arrayCopy.add(deepCopy(schema.getElementType(), obj));
/*     */       }
/* 782 */       return arrayCopy;
/*     */     case BOOLEAN: 
/* 784 */       return new Boolean(((Boolean)value).booleanValue());
/*     */     case BYTES: 
/* 786 */       ByteBuffer byteBufferValue = (ByteBuffer)value;
/* 787 */       int start = byteBufferValue.position();
/* 788 */       int length = byteBufferValue.limit() - start;
/* 789 */       byte[] bytesCopy = new byte[length];
/* 790 */       byteBufferValue.get(bytesCopy, 0, length);
/* 791 */       byteBufferValue.position(start);
/* 792 */       return ByteBuffer.wrap(bytesCopy, 0, length);
/*     */     case DOUBLE: 
/* 794 */       return new Double(((Double)value).doubleValue());
/*     */     
/*     */     case ENUM: 
/* 797 */       return value;
/*     */     case FIXED: 
/* 799 */       return createFixed(null, ((GenericFixed)value).bytes(), schema);
/*     */     case FLOAT: 
/* 801 */       return new Float(((Float)value).floatValue());
/*     */     case INT: 
/* 803 */       return new Integer(((Integer)value).intValue());
/*     */     case LONG: 
/* 805 */       return new Long(((Long)value).longValue());
/*     */     case MAP: 
/* 807 */       Map<CharSequence, Object> mapValue = (Map)value;
/* 808 */       Map<CharSequence, Object> mapCopy = new HashMap(mapValue.size());
/*     */       
/* 810 */       for (Map.Entry<CharSequence, Object> entry : mapValue.entrySet()) {
/* 811 */         mapCopy.put((CharSequence)deepCopy(STRINGS, entry.getKey()), deepCopy(schema.getValueType(), entry.getValue()));
/*     */       }
/*     */       
/* 814 */       return mapCopy;
/*     */     case NULL: 
/* 816 */       return null;
/*     */     case RECORD: 
/* 818 */       IndexedRecord recordValue = (IndexedRecord)value;
/* 819 */       IndexedRecord recordCopy = (IndexedRecord)newRecord(null, schema);
/* 820 */       for (Schema.Field field : schema.getFields()) {
/* 821 */         recordCopy.put(field.pos(), deepCopy(field.schema(), recordValue.get(field.pos())));
/*     */       }
/*     */       
/* 824 */       return recordCopy;
/*     */     
/*     */     case STRING: 
/* 827 */       if ((value instanceof String)) {
/* 828 */         return value;
/*     */       }
/*     */       
/*     */ 
/*     */ 
/* 833 */       if ((value instanceof Utf8))
/*     */       {
/*     */ 
/* 836 */         return new Utf8((Utf8)value);
/*     */       }
/* 838 */       return new Utf8(value.toString());
/*     */     case UNION: 
/* 840 */       return deepCopy((Schema)schema.getTypes().get(resolveUnion(schema, value)), value);
/*     */     }
/*     */     
/* 843 */     throw new AvroRuntimeException("Deep copy failed for schema \"" + schema + "\" and value \"" + value + "\"");
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public Object createFixed(Object old, Schema schema)
/*     */   {
/* 852 */     if (((old instanceof GenericFixed)) && (((GenericFixed)old).bytes().length == schema.getFixedSize()))
/*     */     {
/* 854 */       return old; }
/* 855 */     return new Fixed(schema);
/*     */   }
/*     */   
/*     */ 
/*     */   public Object createFixed(Object old, byte[] bytes, Schema schema)
/*     */   {
/* 861 */     GenericFixed fixed = (GenericFixed)createFixed(old, schema);
/* 862 */     System.arraycopy(bytes, 0, fixed.bytes(), 0, schema.getFixedSize());
/* 863 */     return fixed;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public Object newRecord(Object old, Schema schema)
/*     */   {
/* 875 */     if ((old instanceof IndexedRecord)) {
/* 876 */       IndexedRecord record = (IndexedRecord)old;
/* 877 */       if (record.getSchema() == schema)
/* 878 */         return record;
/*     */     }
/* 880 */     return new Record(schema);
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\apache\avro\generic\GenericData.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */