/*     */ package org.apache.avro.generic;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import org.apache.avro.AvroRuntimeException;
/*     */ import org.apache.avro.Schema;
/*     */ import org.apache.avro.Schema.Field;
/*     */ import org.apache.avro.data.RecordBuilderBase;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class GenericRecordBuilder
/*     */   extends RecordBuilderBase<GenericData.Record>
/*     */ {
/*     */   private final GenericData.Record record;
/*     */   
/*     */   public GenericRecordBuilder(Schema schema)
/*     */   {
/*  37 */     super(schema, GenericData.get());
/*  38 */     this.record = new GenericData.Record(schema);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public GenericRecordBuilder(GenericRecordBuilder other)
/*     */   {
/*  46 */     super(other, GenericData.get());
/*  47 */     this.record = new GenericData.Record(other.record, true);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public GenericRecordBuilder(GenericData.Record other)
/*     */   {
/*  55 */     super(other.getSchema(), GenericData.get());
/*  56 */     this.record = new GenericData.Record(other, true);
/*     */     
/*     */ 
/*  59 */     for (Schema.Field f : schema().getFields()) {
/*  60 */       Object value = other.get(f.pos());
/*     */       
/*     */ 
/*  63 */       if (isValidValue(f, value)) {
/*  64 */         set(f, data().deepCopy(f.schema(), value));
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public Object get(String fieldName)
/*     */   {
/*  75 */     return get(schema().getField(fieldName));
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public Object get(Schema.Field field)
/*     */   {
/*  84 */     return get(field.pos());
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected Object get(int pos)
/*     */   {
/*  93 */     return this.record.get(pos);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public GenericRecordBuilder set(String fieldName, Object value)
/*     */   {
/* 103 */     return set(schema().getField(fieldName), value);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public GenericRecordBuilder set(Schema.Field field, Object value)
/*     */   {
/* 113 */     return set(field, field.pos(), value);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected GenericRecordBuilder set(int pos, Object value)
/*     */   {
/* 123 */     return set(fields()[pos], pos, value);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private GenericRecordBuilder set(Schema.Field field, int pos, Object value)
/*     */   {
/* 134 */     validate(field, value);
/* 135 */     this.record.put(pos, value);
/* 136 */     fieldSetFlags()[pos] = 1;
/* 137 */     return this;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public boolean has(String fieldName)
/*     */   {
/* 146 */     return has(schema().getField(fieldName));
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public boolean has(Schema.Field field)
/*     */   {
/* 155 */     return has(field.pos());
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected boolean has(int pos)
/*     */   {
/* 164 */     return fieldSetFlags()[pos];
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public GenericRecordBuilder clear(String fieldName)
/*     */   {
/* 173 */     return clear(schema().getField(fieldName));
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public GenericRecordBuilder clear(Schema.Field field)
/*     */   {
/* 182 */     return clear(field.pos());
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected GenericRecordBuilder clear(int pos)
/*     */   {
/* 191 */     this.record.put(pos, null);
/* 192 */     fieldSetFlags()[pos] = 0;
/* 193 */     return this;
/*     */   }
/*     */   
/*     */   public GenericData.Record build()
/*     */   {
/*     */     GenericData.Record record;
/*     */     try {
/* 200 */       record = new GenericData.Record(schema());
/*     */     } catch (Exception e) {
/* 202 */       throw new AvroRuntimeException(e);
/*     */     }
/*     */     
/* 205 */     for (Schema.Field field : fields()) {
/*     */       Object value;
/*     */       try {
/* 208 */         value = getWithDefault(field);
/*     */       } catch (IOException e) {
/* 210 */         throw new AvroRuntimeException(e);
/*     */       }
/* 212 */       if (value != null) {
/* 213 */         record.put(field.pos(), value);
/*     */       }
/*     */     }
/*     */     
/* 217 */     return record;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private Object getWithDefault(Schema.Field field)
/*     */     throws IOException
/*     */   {
/* 231 */     return fieldSetFlags()[field.pos()] != 0 ? this.record.get(field.pos()) : defaultValue(field);
/*     */   }
/*     */   
/*     */ 
/*     */   public int hashCode()
/*     */   {
/* 237 */     int prime = 31;
/* 238 */     int result = super.hashCode();
/* 239 */     result = 31 * result + (this.record == null ? 0 : this.record.hashCode());
/* 240 */     return result;
/*     */   }
/*     */   
/*     */   public boolean equals(Object obj)
/*     */   {
/* 245 */     if (this == obj)
/* 246 */       return true;
/* 247 */     if (!super.equals(obj))
/* 248 */       return false;
/* 249 */     if (getClass() != obj.getClass())
/* 250 */       return false;
/* 251 */     GenericRecordBuilder other = (GenericRecordBuilder)obj;
/* 252 */     if (this.record == null) {
/* 253 */       if (other.record != null)
/* 254 */         return false;
/* 255 */     } else if (!this.record.equals(other.record))
/* 256 */       return false;
/* 257 */     return true;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\apache\avro\generic\GenericRecordBuilder.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */