/*     */ package org.apache.avro.io;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.OutputStream;
/*     */ import org.apache.avro.AvroRuntimeException;
/*     */ import org.apache.avro.Schema;
/*     */ import org.codehaus.jackson.JsonGenerator;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class EncoderFactory
/*     */ {
/*     */   private static final int DEFAULT_BUFFER_SIZE = 2048;
/*     */   private static final int DEFAULT_BLOCK_BUFFER_SIZE = 65536;
/*     */   private static final int MIN_BLOCK_BUFFER_SIZE = 64;
/*     */   private static final int MAX_BLOCK_BUFFER_SIZE = 1073741824;
/*  49 */   private static final EncoderFactory DEFAULT_FACTORY = new DefaultEncoderFactory(null);
/*     */   protected int binaryBufferSize;
/*     */   
/*  52 */   public EncoderFactory() { this.binaryBufferSize = 2048;
/*  53 */     this.binaryBlockSize = 65536;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public static EncoderFactory get()
/*     */   {
/*  60 */     return DEFAULT_FACTORY;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public EncoderFactory configureBufferSize(int size)
/*     */   {
/*  82 */     if (size < 32)
/*  83 */       size = 32;
/*  84 */     if (size > 16777216)
/*  85 */       size = 16777216;
/*  86 */     this.binaryBufferSize = size;
/*  87 */     return this;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public int getBufferSize()
/*     */   {
/*  98 */     return this.binaryBufferSize;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public EncoderFactory configureBlockSize(int size)
/*     */   {
/* 118 */     if (size < 64)
/* 119 */       size = 64;
/* 120 */     if (size > 1073741824)
/* 121 */       size = 1073741824;
/* 122 */     this.binaryBufferSize = size;
/* 123 */     return this;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public int getBlockSize()
/*     */   {
/* 137 */     return this.binaryBlockSize;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public BinaryEncoder binaryEncoder(OutputStream out, BinaryEncoder reuse)
/*     */   {
/* 171 */     if ((null == reuse) || (!reuse.getClass().equals(BufferedBinaryEncoder.class))) {
/* 172 */       return new BufferedBinaryEncoder(out, this.binaryBufferSize);
/*     */     }
/* 174 */     return ((BufferedBinaryEncoder)reuse).configure(out, this.binaryBufferSize);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected int binaryBlockSize;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public BinaryEncoder directBinaryEncoder(OutputStream out, BinaryEncoder reuse)
/*     */   {
/* 212 */     if ((null == reuse) || (!reuse.getClass().equals(DirectBinaryEncoder.class))) {
/* 213 */       return new DirectBinaryEncoder(out);
/*     */     }
/* 215 */     return ((DirectBinaryEncoder)reuse).configure(out);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public BinaryEncoder blockingBinaryEncoder(OutputStream out, BinaryEncoder reuse)
/*     */   {
/* 253 */     if ((null == reuse) || (!reuse.getClass().equals(BlockingBinaryEncoder.class))) {
/* 254 */       return new BlockingBinaryEncoder(out, this.binaryBlockSize, 32);
/*     */     }
/* 256 */     return ((BlockingBinaryEncoder)reuse).configure(out, this.binaryBlockSize, 32);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JsonEncoder jsonEncoder(Schema schema, OutputStream out)
/*     */     throws IOException
/*     */   {
/* 278 */     return new JsonEncoder(schema, out);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JsonEncoder jsonEncoder(Schema schema, JsonGenerator gen)
/*     */     throws IOException
/*     */   {
/* 299 */     return new JsonEncoder(schema, gen);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public ValidatingEncoder validatingEncoder(Schema schema, Encoder encoder)
/*     */     throws IOException
/*     */   {
/* 322 */     return new ValidatingEncoder(schema, encoder);
/*     */   }
/*     */   
/*     */   private static class DefaultEncoderFactory extends EncoderFactory
/*     */   {
/*     */     public EncoderFactory configureBlockSize(int size)
/*     */     {
/* 329 */       throw new AvroRuntimeException("Default EncoderFactory cannot be configured");
/*     */     }
/*     */     
/*     */     public EncoderFactory configureBufferSize(int size) {
/* 333 */       throw new AvroRuntimeException("Default EncoderFactory cannot be configured");
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\apache\avro\io\EncoderFactory.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */