/*     */ package org.apache.avro.io;
/*     */ 
/*     */ import java.io.EOFException;
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.math.BigDecimal;
/*     */ import java.math.BigInteger;
/*     */ import java.nio.ByteBuffer;
/*     */ import java.util.ArrayList;
/*     */ import java.util.HashMap;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import java.util.Stack;
/*     */ import org.apache.avro.AvroTypeException;
/*     */ import org.apache.avro.Schema;
/*     */ import org.apache.avro.io.parsing.JsonGrammarGenerator;
/*     */ import org.apache.avro.io.parsing.Parser.ActionHandler;
/*     */ import org.apache.avro.io.parsing.SkipParser;
/*     */ import org.apache.avro.io.parsing.Symbol;
/*     */ import org.apache.avro.io.parsing.Symbol.Alternative;
/*     */ import org.apache.avro.io.parsing.Symbol.EnumLabelsAction;
/*     */ import org.apache.avro.io.parsing.Symbol.FieldAdjustAction;
/*     */ import org.apache.avro.io.parsing.Symbol.IntCheckAction;
/*     */ import org.apache.avro.util.Utf8;
/*     */ import org.codehaus.jackson.Base64Variant;
/*     */ import org.codehaus.jackson.JsonFactory;
/*     */ import org.codehaus.jackson.JsonLocation;
/*     */ import org.codehaus.jackson.JsonParser;
/*     */ import org.codehaus.jackson.JsonParser.NumberType;
/*     */ import org.codehaus.jackson.JsonStreamContext;
/*     */ import org.codehaus.jackson.JsonToken;
/*     */ import org.codehaus.jackson.ObjectCodec;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class JsonDecoder
/*     */   extends ParsingDecoder
/*     */   implements Parser.ActionHandler
/*     */ {
/*     */   private JsonParser in;
/*  55 */   private static JsonFactory jsonFactory = new JsonFactory();
/*  56 */   Stack<ReorderBuffer> reorderBuffers = new Stack();
/*     */   ReorderBuffer currentReorderBuffer;
/*     */   static final String CHARSET = "ISO-8859-1";
/*     */   
/*  60 */   private static class ReorderBuffer { public Map<String, List<JsonDecoder.JsonElement>> savedFields = new HashMap();
/*  61 */     public JsonParser origParser = null;
/*     */   }
/*     */   
/*     */   private JsonDecoder(Symbol root, InputStream in)
/*     */     throws IOException
/*     */   {
/*  67 */     super(root);
/*  68 */     configure(in);
/*     */   }
/*     */   
/*     */   private JsonDecoder(Symbol root, String in) throws IOException {
/*  72 */     super(root);
/*  73 */     configure(in);
/*     */   }
/*     */   
/*     */   JsonDecoder(Schema schema, InputStream in) throws IOException {
/*  77 */     this(getSymbol(schema), in);
/*     */   }
/*     */   
/*     */   JsonDecoder(Schema schema, String in) throws IOException {
/*  81 */     this(getSymbol(schema), in);
/*     */   }
/*     */   
/*     */   private static Symbol getSymbol(Schema schema) {
/*  85 */     if (null == schema) {
/*  86 */       throw new NullPointerException("Schema cannot be null!");
/*     */     }
/*  88 */     return new JsonGrammarGenerator().generate(schema);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JsonDecoder configure(InputStream in)
/*     */     throws IOException
/*     */   {
/* 104 */     if (null == in) {
/* 105 */       throw new NullPointerException("InputStream to read from cannot be null!");
/*     */     }
/* 107 */     this.parser.reset();
/* 108 */     this.in = jsonFactory.createJsonParser(in);
/* 109 */     this.in.nextToken();
/* 110 */     return this;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JsonDecoder configure(String in)
/*     */     throws IOException
/*     */   {
/* 126 */     if (null == in) {
/* 127 */       throw new NullPointerException("String to read from cannot be null!");
/*     */     }
/* 129 */     this.parser.reset();
/* 130 */     this.in = new JsonFactory().createJsonParser(in);
/* 131 */     this.in.nextToken();
/* 132 */     return this;
/*     */   }
/*     */   
/*     */   private void advance(Symbol symbol) throws IOException {
/* 136 */     this.parser.processTrailingImplicitActions();
/* 137 */     if ((this.in.getCurrentToken() == null) && (this.parser.depth() == 1))
/* 138 */       throw new EOFException();
/* 139 */     this.parser.advance(symbol);
/*     */   }
/*     */   
/*     */   public void readNull() throws IOException
/*     */   {
/* 144 */     advance(Symbol.NULL);
/* 145 */     if (this.in.getCurrentToken() == JsonToken.VALUE_NULL) {
/* 146 */       this.in.nextToken();
/*     */     } else {
/* 148 */       throw error("null");
/*     */     }
/*     */   }
/*     */   
/*     */   public boolean readBoolean() throws IOException
/*     */   {
/* 154 */     advance(Symbol.BOOLEAN);
/* 155 */     JsonToken t = this.in.getCurrentToken();
/* 156 */     if ((t == JsonToken.VALUE_TRUE) || (t == JsonToken.VALUE_FALSE)) {
/* 157 */       this.in.nextToken();
/* 158 */       return t == JsonToken.VALUE_TRUE;
/*     */     }
/* 160 */     throw error("boolean");
/*     */   }
/*     */   
/*     */   public int readInt()
/*     */     throws IOException
/*     */   {
/* 166 */     advance(Symbol.INT);
/* 167 */     if (this.in.getCurrentToken().isNumeric()) {
/* 168 */       int result = this.in.getIntValue();
/* 169 */       this.in.nextToken();
/* 170 */       return result;
/*     */     }
/* 172 */     throw error("int");
/*     */   }
/*     */   
/*     */   public long readLong()
/*     */     throws IOException
/*     */   {
/* 178 */     advance(Symbol.LONG);
/* 179 */     if (this.in.getCurrentToken().isNumeric()) {
/* 180 */       long result = this.in.getLongValue();
/* 181 */       this.in.nextToken();
/* 182 */       return result;
/*     */     }
/* 184 */     throw error("long");
/*     */   }
/*     */   
/*     */   public float readFloat()
/*     */     throws IOException
/*     */   {
/* 190 */     advance(Symbol.FLOAT);
/* 191 */     if (this.in.getCurrentToken().isNumeric()) {
/* 192 */       float result = this.in.getFloatValue();
/* 193 */       this.in.nextToken();
/* 194 */       return result;
/*     */     }
/* 196 */     throw error("float");
/*     */   }
/*     */   
/*     */   public double readDouble()
/*     */     throws IOException
/*     */   {
/* 202 */     advance(Symbol.DOUBLE);
/* 203 */     if (this.in.getCurrentToken().isNumeric()) {
/* 204 */       double result = this.in.getDoubleValue();
/* 205 */       this.in.nextToken();
/* 206 */       return result;
/*     */     }
/* 208 */     throw error("double");
/*     */   }
/*     */   
/*     */   public Utf8 readString(Utf8 old)
/*     */     throws IOException
/*     */   {
/* 214 */     return new Utf8(readString());
/*     */   }
/*     */   
/*     */   public String readString() throws IOException
/*     */   {
/* 219 */     advance(Symbol.STRING);
/* 220 */     if (this.parser.topSymbol() == Symbol.MAP_KEY_MARKER) {
/* 221 */       this.parser.advance(Symbol.MAP_KEY_MARKER);
/* 222 */       if (this.in.getCurrentToken() != JsonToken.FIELD_NAME) {
/* 223 */         throw error("map-key");
/*     */       }
/*     */     }
/* 226 */     else if (this.in.getCurrentToken() != JsonToken.VALUE_STRING) {
/* 227 */       throw error("string");
/*     */     }
/*     */     
/* 230 */     String result = this.in.getText();
/* 231 */     this.in.nextToken();
/* 232 */     return result;
/*     */   }
/*     */   
/*     */   public void skipString() throws IOException
/*     */   {
/* 237 */     advance(Symbol.STRING);
/* 238 */     if (this.parser.topSymbol() == Symbol.MAP_KEY_MARKER) {
/* 239 */       this.parser.advance(Symbol.MAP_KEY_MARKER);
/* 240 */       if (this.in.getCurrentToken() != JsonToken.FIELD_NAME) {
/* 241 */         throw error("map-key");
/*     */       }
/*     */     }
/* 244 */     else if (this.in.getCurrentToken() != JsonToken.VALUE_STRING) {
/* 245 */       throw error("string");
/*     */     }
/*     */     
/* 248 */     this.in.nextToken();
/*     */   }
/*     */   
/*     */   public ByteBuffer readBytes(ByteBuffer old) throws IOException
/*     */   {
/* 253 */     advance(Symbol.BYTES);
/* 254 */     if (this.in.getCurrentToken() == JsonToken.VALUE_STRING) {
/* 255 */       byte[] result = readByteArray();
/* 256 */       this.in.nextToken();
/* 257 */       return ByteBuffer.wrap(result);
/*     */     }
/* 259 */     throw error("bytes");
/*     */   }
/*     */   
/*     */   private byte[] readByteArray() throws IOException
/*     */   {
/* 264 */     byte[] result = this.in.getText().getBytes("ISO-8859-1");
/* 265 */     return result;
/*     */   }
/*     */   
/*     */   public void skipBytes() throws IOException
/*     */   {
/* 270 */     advance(Symbol.BYTES);
/* 271 */     if (this.in.getCurrentToken() == JsonToken.VALUE_STRING) {
/* 272 */       this.in.nextToken();
/*     */     } else {
/* 274 */       throw error("bytes");
/*     */     }
/*     */   }
/*     */   
/*     */   private void checkFixed(int size) throws IOException {
/* 279 */     advance(Symbol.FIXED);
/* 280 */     Symbol.IntCheckAction top = (Symbol.IntCheckAction)this.parser.popSymbol();
/* 281 */     if (size != top.size) {
/* 282 */       throw new AvroTypeException("Incorrect length for fixed binary: expected " + top.size + " but received " + size + " bytes.");
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */   public void readFixed(byte[] bytes, int start, int len)
/*     */     throws IOException
/*     */   {
/* 290 */     checkFixed(len);
/* 291 */     if (this.in.getCurrentToken() == JsonToken.VALUE_STRING) {
/* 292 */       byte[] result = readByteArray();
/* 293 */       this.in.nextToken();
/* 294 */       if (result.length != len) {
/* 295 */         throw new AvroTypeException("Expected fixed length " + len + ", but got" + result.length);
/*     */       }
/*     */       
/* 298 */       System.arraycopy(result, 0, bytes, start, len);
/*     */     } else {
/* 300 */       throw error("fixed");
/*     */     }
/*     */   }
/*     */   
/*     */   public void skipFixed(int length) throws IOException
/*     */   {
/* 306 */     checkFixed(length);
/* 307 */     doSkipFixed(length);
/*     */   }
/*     */   
/*     */   private void doSkipFixed(int length) throws IOException {
/* 311 */     if (this.in.getCurrentToken() == JsonToken.VALUE_STRING) {
/* 312 */       byte[] result = readByteArray();
/* 313 */       this.in.nextToken();
/* 314 */       if (result.length != length) {
/* 315 */         throw new AvroTypeException("Expected fixed length " + length + ", but got" + result.length);
/*     */       }
/*     */     }
/*     */     else {
/* 319 */       throw error("fixed");
/*     */     }
/*     */   }
/*     */   
/*     */   protected void skipFixed() throws IOException
/*     */   {
/* 325 */     advance(Symbol.FIXED);
/* 326 */     Symbol.IntCheckAction top = (Symbol.IntCheckAction)this.parser.popSymbol();
/* 327 */     doSkipFixed(top.size);
/*     */   }
/*     */   
/*     */   public int readEnum() throws IOException
/*     */   {
/* 332 */     advance(Symbol.ENUM);
/* 333 */     Symbol.EnumLabelsAction top = (Symbol.EnumLabelsAction)this.parser.popSymbol();
/* 334 */     if (this.in.getCurrentToken() == JsonToken.VALUE_STRING) {
/* 335 */       this.in.getText();
/* 336 */       int n = top.findLabel(this.in.getText());
/* 337 */       if (n >= 0) {
/* 338 */         this.in.nextToken();
/* 339 */         return n;
/*     */       }
/* 341 */       throw new AvroTypeException("Unknown symbol in enum " + this.in.getText());
/*     */     }
/* 343 */     throw error("fixed");
/*     */   }
/*     */   
/*     */   public long readArrayStart()
/*     */     throws IOException
/*     */   {
/* 349 */     advance(Symbol.ARRAY_START);
/* 350 */     if (this.in.getCurrentToken() == JsonToken.START_ARRAY) {
/* 351 */       this.in.nextToken();
/* 352 */       return doArrayNext();
/*     */     }
/* 354 */     throw error("array-start");
/*     */   }
/*     */   
/*     */   public long arrayNext()
/*     */     throws IOException
/*     */   {
/* 360 */     advance(Symbol.ITEM_END);
/* 361 */     return doArrayNext();
/*     */   }
/*     */   
/*     */   private long doArrayNext() throws IOException {
/* 365 */     if (this.in.getCurrentToken() == JsonToken.END_ARRAY) {
/* 366 */       this.parser.advance(Symbol.ARRAY_END);
/* 367 */       this.in.nextToken();
/* 368 */       return 0L;
/*     */     }
/* 370 */     return 1L;
/*     */   }
/*     */   
/*     */   public long skipArray()
/*     */     throws IOException
/*     */   {
/* 376 */     advance(Symbol.ARRAY_START);
/* 377 */     if (this.in.getCurrentToken() == JsonToken.START_ARRAY) {
/* 378 */       this.in.skipChildren();
/* 379 */       this.in.nextToken();
/* 380 */       advance(Symbol.ARRAY_END);
/*     */     } else {
/* 382 */       throw error("array-start");
/*     */     }
/* 384 */     return 0L;
/*     */   }
/*     */   
/*     */   public long readMapStart() throws IOException
/*     */   {
/* 389 */     advance(Symbol.MAP_START);
/* 390 */     if (this.in.getCurrentToken() == JsonToken.START_OBJECT) {
/* 391 */       this.in.nextToken();
/* 392 */       return doMapNext();
/*     */     }
/* 394 */     throw error("map-start");
/*     */   }
/*     */   
/*     */   public long mapNext()
/*     */     throws IOException
/*     */   {
/* 400 */     advance(Symbol.ITEM_END);
/* 401 */     return doMapNext();
/*     */   }
/*     */   
/*     */   private long doMapNext() throws IOException {
/* 405 */     if (this.in.getCurrentToken() == JsonToken.END_OBJECT) {
/* 406 */       this.in.nextToken();
/* 407 */       advance(Symbol.MAP_END);
/* 408 */       return 0L;
/*     */     }
/* 410 */     return 1L;
/*     */   }
/*     */   
/*     */   public long skipMap()
/*     */     throws IOException
/*     */   {
/* 416 */     advance(Symbol.MAP_START);
/* 417 */     if (this.in.getCurrentToken() == JsonToken.START_OBJECT) {
/* 418 */       this.in.skipChildren();
/* 419 */       this.in.nextToken();
/* 420 */       advance(Symbol.MAP_END);
/*     */     } else {
/* 422 */       throw error("map-start");
/*     */     }
/* 424 */     return 0L;
/*     */   }
/*     */   
/*     */   public int readIndex() throws IOException
/*     */   {
/* 429 */     advance(Symbol.UNION);
/* 430 */     Symbol.Alternative a = (Symbol.Alternative)this.parser.popSymbol();
/*     */     
/*     */     String label;
/* 433 */     if (this.in.getCurrentToken() == JsonToken.VALUE_NULL) {
/* 434 */       label = "null";
/* 435 */     } else if ((this.in.getCurrentToken() == JsonToken.START_OBJECT) && (this.in.nextToken() == JsonToken.FIELD_NAME))
/*     */     {
/* 437 */       String label = this.in.getText();
/* 438 */       this.in.nextToken();
/* 439 */       this.parser.pushSymbol(Symbol.UNION_END);
/*     */     } else {
/* 441 */       throw error("start-union"); }
/*     */     String label;
/* 443 */     int n = a.findLabel(label);
/* 444 */     if (n < 0)
/* 445 */       throw new AvroTypeException("Unknown union branch " + label);
/* 446 */     this.parser.pushSymbol(a.getSymbol(n));
/* 447 */     return n;
/*     */   }
/*     */   
/*     */   public Symbol doAction(Symbol input, Symbol top) throws IOException
/*     */   {
/* 452 */     if ((top instanceof Symbol.FieldAdjustAction)) {
/* 453 */       Symbol.FieldAdjustAction fa = (Symbol.FieldAdjustAction)top;
/* 454 */       String name = fa.fname;
/* 455 */       if (this.currentReorderBuffer != null) {
/* 456 */         List<JsonElement> node = (List)this.currentReorderBuffer.savedFields.get(name);
/* 457 */         if (node != null) {
/* 458 */           this.currentReorderBuffer.savedFields.remove(name);
/* 459 */           this.currentReorderBuffer.origParser = this.in;
/* 460 */           this.in = makeParser(node);
/* 461 */           return null;
/*     */         }
/*     */       }
/* 464 */       if (this.in.getCurrentToken() == JsonToken.FIELD_NAME) {
/*     */         do {
/* 466 */           String fn = this.in.getText();
/* 467 */           this.in.nextToken();
/* 468 */           if (name.equals(fn)) {
/* 469 */             return null;
/*     */           }
/* 471 */           if (this.currentReorderBuffer == null) {
/* 472 */             this.currentReorderBuffer = new ReorderBuffer(null);
/*     */           }
/* 474 */           this.currentReorderBuffer.savedFields.put(fn, getVaueAsTree(this.in));
/*     */         }
/* 476 */         while (this.in.getCurrentToken() == JsonToken.FIELD_NAME);
/* 477 */         throw new AvroTypeException("Expected field name not found: " + fa.fname);
/*     */       }
/* 479 */     } else if (top == Symbol.FIELD_END) {
/* 480 */       if ((this.currentReorderBuffer != null) && (this.currentReorderBuffer.origParser != null)) {
/* 481 */         this.in = this.currentReorderBuffer.origParser;
/* 482 */         this.currentReorderBuffer.origParser = null;
/*     */       }
/* 484 */     } else if (top == Symbol.RECORD_START) {
/* 485 */       if (this.in.getCurrentToken() == JsonToken.START_OBJECT) {
/* 486 */         this.in.nextToken();
/* 487 */         this.reorderBuffers.push(this.currentReorderBuffer);
/* 488 */         this.currentReorderBuffer = null;
/*     */       } else {
/* 490 */         throw error("record-start");
/*     */       }
/* 492 */     } else if ((top == Symbol.RECORD_END) || (top == Symbol.UNION_END)) {
/* 493 */       if (this.in.getCurrentToken() == JsonToken.END_OBJECT) {
/* 494 */         this.in.nextToken();
/* 495 */         if (top == Symbol.RECORD_END) {
/* 496 */           if ((this.currentReorderBuffer != null) && (!this.currentReorderBuffer.savedFields.isEmpty())) {
/* 497 */             throw error("Unknown fields: " + this.currentReorderBuffer.savedFields.keySet());
/*     */           }
/* 499 */           this.currentReorderBuffer = ((ReorderBuffer)this.reorderBuffers.pop());
/*     */         }
/*     */       } else {
/* 502 */         throw error(top == Symbol.RECORD_END ? "record-end" : "union-end");
/*     */       }
/*     */     } else {
/* 505 */       throw new AvroTypeException("Unknown action symbol " + top);
/*     */     }
/* 507 */     return null;
/*     */   }
/*     */   
/*     */   private static class JsonElement {
/*     */     public final JsonToken token;
/*     */     public final String value;
/*     */     
/* 514 */     public JsonElement(JsonToken t, String value) { this.token = t;
/* 515 */       this.value = value;
/*     */     }
/*     */     
/*     */     public JsonElement(JsonToken t) {
/* 519 */       this(t, null);
/*     */     }
/*     */   }
/*     */   
/*     */   private static List<JsonElement> getVaueAsTree(JsonParser in) throws IOException {
/* 524 */     int level = 0;
/* 525 */     List<JsonElement> result = new ArrayList();
/*     */     do {
/* 527 */       JsonToken t = in.getCurrentToken();
/* 528 */       switch (t) {
/*     */       case START_OBJECT: 
/*     */       case START_ARRAY: 
/* 531 */         level++;
/* 532 */         result.add(new JsonElement(t));
/* 533 */         break;
/*     */       case END_OBJECT: 
/*     */       case END_ARRAY: 
/* 536 */         level--;
/* 537 */         result.add(new JsonElement(t));
/* 538 */         break;
/*     */       case FIELD_NAME: 
/*     */       case VALUE_STRING: 
/*     */       case VALUE_NUMBER_INT: 
/*     */       case VALUE_NUMBER_FLOAT: 
/*     */       case VALUE_TRUE: 
/*     */       case VALUE_FALSE: 
/*     */       case VALUE_NULL: 
/* 546 */         result.add(new JsonElement(t, in.getText()));
/*     */       }
/*     */       
/* 549 */       in.nextToken();
/* 550 */     } while (level != 0);
/* 551 */     result.add(new JsonElement(null));
/* 552 */     return result;
/*     */   }
/*     */   
/*     */   private JsonParser makeParser(final List<JsonElement> elements) throws IOException {
/* 556 */     new JsonParser() {
/* 557 */       int pos = 0;
/*     */       
/*     */       public ObjectCodec getCodec()
/*     */       {
/* 561 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public void setCodec(ObjectCodec c)
/*     */       {
/* 566 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public void close() throws IOException
/*     */       {
/* 571 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public JsonToken nextToken() throws IOException
/*     */       {
/* 576 */         this.pos += 1;
/* 577 */         return ((JsonDecoder.JsonElement)elements.get(this.pos)).token;
/*     */       }
/*     */       
/*     */       public JsonParser skipChildren() throws IOException
/*     */       {
/* 582 */         int level = 0;
/*     */         do {
/* 584 */           switch (JsonDecoder.2.$SwitchMap$org$codehaus$jackson$JsonToken[((JsonDecoder.JsonElement)elements.get(this.pos++)).token.ordinal()]) {
/*     */           case 1: 
/*     */           case 2: 
/* 587 */             level++;
/* 588 */             break;
/*     */           case 3: 
/*     */           case 4: 
/* 591 */             level--;
/*     */           }
/*     */           
/* 594 */         } while (level > 0);
/* 595 */         return this;
/*     */       }
/*     */       
/*     */       public boolean isClosed()
/*     */       {
/* 600 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public String getCurrentName() throws IOException
/*     */       {
/* 605 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public JsonStreamContext getParsingContext()
/*     */       {
/* 610 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public JsonLocation getTokenLocation()
/*     */       {
/* 615 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public JsonLocation getCurrentLocation()
/*     */       {
/* 620 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public String getText() throws IOException
/*     */       {
/* 625 */         return ((JsonDecoder.JsonElement)elements.get(this.pos)).value;
/*     */       }
/*     */       
/*     */       public char[] getTextCharacters() throws IOException
/*     */       {
/* 630 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public int getTextLength() throws IOException
/*     */       {
/* 635 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public int getTextOffset() throws IOException
/*     */       {
/* 640 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public Number getNumberValue() throws IOException
/*     */       {
/* 645 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public JsonParser.NumberType getNumberType() throws IOException
/*     */       {
/* 650 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public int getIntValue() throws IOException
/*     */       {
/* 655 */         return Integer.parseInt(getText());
/*     */       }
/*     */       
/*     */       public long getLongValue() throws IOException
/*     */       {
/* 660 */         return Long.parseLong(getText());
/*     */       }
/*     */       
/*     */       public BigInteger getBigIntegerValue() throws IOException
/*     */       {
/* 665 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public float getFloatValue() throws IOException
/*     */       {
/* 670 */         return Float.parseFloat(getText());
/*     */       }
/*     */       
/*     */       public double getDoubleValue() throws IOException
/*     */       {
/* 675 */         return Double.parseDouble(getText());
/*     */       }
/*     */       
/*     */       public BigDecimal getDecimalValue() throws IOException
/*     */       {
/* 680 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public byte[] getBinaryValue(Base64Variant b64variant)
/*     */         throws IOException
/*     */       {
/* 686 */         throw new UnsupportedOperationException();
/*     */       }
/*     */       
/*     */       public JsonToken getCurrentToken()
/*     */       {
/* 691 */         return ((JsonDecoder.JsonElement)elements.get(this.pos)).token;
/*     */       }
/*     */     };
/*     */   }
/*     */   
/*     */   private AvroTypeException error(String type) {
/* 697 */     return new AvroTypeException("Expected " + type + ". Got " + this.in.getCurrentToken());
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\apache\avro\io\JsonDecoder.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */