/*     */ package org.codehaus.jackson.map.ser;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.lang.reflect.InvocationTargetException;
/*     */ import java.lang.reflect.Type;
/*     */ import org.codehaus.jackson.JsonGenerationException;
/*     */ import org.codehaus.jackson.JsonGenerator;
/*     */ import org.codehaus.jackson.JsonNode;
/*     */ import org.codehaus.jackson.map.JsonMappingException;
/*     */ import org.codehaus.jackson.map.JsonSerializer;
/*     */ import org.codehaus.jackson.map.SerializationConfig.Feature;
/*     */ import org.codehaus.jackson.map.SerializerProvider;
/*     */ import org.codehaus.jackson.map.annotate.JacksonStdImpl;
/*     */ import org.codehaus.jackson.node.JsonNodeFactory;
/*     */ import org.codehaus.jackson.node.ObjectNode;
/*     */ import org.codehaus.jackson.schema.SchemaAware;
/*     */ import org.codehaus.jackson.type.JavaType;
/*     */ 
/*     */ 
/*     */ public abstract class SerializerBase<T>
/*     */   extends JsonSerializer<T>
/*     */   implements SchemaAware
/*     */ {
/*     */   protected final Class<T> _handledType;
/*     */   
/*     */   protected SerializerBase(Class<T> t)
/*     */   {
/*  28 */     this._handledType = t;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   protected SerializerBase(JavaType type)
/*     */   {
/*  36 */     this._handledType = type.getRawClass();
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected SerializerBase(Class<?> t, boolean dummy)
/*     */   {
/*  45 */     this._handledType = t;
/*     */   }
/*     */   
/*     */   public final Class<T> handledType() {
/*  49 */     return this._handledType;
/*     */   }
/*     */   
/*     */   public abstract void serialize(T paramT, JsonGenerator paramJsonGenerator, SerializerProvider paramSerializerProvider)
/*     */     throws IOException, JsonGenerationException;
/*     */   
/*     */   public abstract JsonNode getSchema(SerializerProvider paramSerializerProvider, Type paramType) throws JsonMappingException;
/*     */   
/*     */   protected ObjectNode createObjectNode()
/*     */   {
/*  59 */     return JsonNodeFactory.instance.objectNode();
/*     */   }
/*     */   
/*     */   protected ObjectNode createSchemaNode(String type)
/*     */   {
/*  64 */     ObjectNode schema = createObjectNode();
/*  65 */     schema.put("type", type);
/*  66 */     return schema;
/*     */   }
/*     */   
/*     */   protected ObjectNode createSchemaNode(String type, boolean isOptional)
/*     */   {
/*  71 */     ObjectNode schema = createSchemaNode(type);
/*     */     
/*  73 */     if (!isOptional) {
/*  74 */       schema.put("required", !isOptional);
/*     */     }
/*  76 */     return schema;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected boolean isDefaultSerializer(JsonSerializer<?> serializer)
/*     */   {
/*  89 */     return (serializer != null) && (serializer.getClass().getAnnotation(JacksonStdImpl.class) != null);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void wrapAndThrow(SerializerProvider provider, Throwable t, Object bean, String fieldName)
/*     */     throws IOException
/*     */   {
/* 112 */     while (((t instanceof InvocationTargetException)) && (t.getCause() != null)) {
/* 113 */       t = t.getCause();
/*     */     }
/*     */     
/* 116 */     if ((t instanceof Error)) {
/* 117 */       throw ((Error)t);
/*     */     }
/*     */     
/* 120 */     boolean wrap = (provider == null) || (provider.isEnabled(SerializationConfig.Feature.WRAP_EXCEPTIONS));
/* 121 */     if ((t instanceof IOException)) {
/* 122 */       if ((!wrap) || (!(t instanceof JsonMappingException))) {
/* 123 */         throw ((IOException)t);
/*     */       }
/* 125 */     } else if ((!wrap) && 
/* 126 */       ((t instanceof RuntimeException))) {
/* 127 */       throw ((RuntimeException)t);
/*     */     }
/*     */     
/*     */ 
/* 131 */     throw JsonMappingException.wrapWithPath(t, bean, fieldName);
/*     */   }
/*     */   
/*     */ 
/*     */   public void wrapAndThrow(SerializerProvider provider, Throwable t, Object bean, int index)
/*     */     throws IOException
/*     */   {
/* 138 */     while (((t instanceof InvocationTargetException)) && (t.getCause() != null)) {
/* 139 */       t = t.getCause();
/*     */     }
/*     */     
/* 142 */     if ((t instanceof Error)) {
/* 143 */       throw ((Error)t);
/*     */     }
/*     */     
/* 146 */     boolean wrap = (provider == null) || (provider.isEnabled(SerializationConfig.Feature.WRAP_EXCEPTIONS));
/* 147 */     if ((t instanceof IOException)) {
/* 148 */       if ((!wrap) || (!(t instanceof JsonMappingException))) {
/* 149 */         throw ((IOException)t);
/*     */       }
/* 151 */     } else if ((!wrap) && 
/* 152 */       ((t instanceof RuntimeException))) {
/* 153 */       throw ((RuntimeException)t);
/*     */     }
/*     */     
/*     */ 
/* 157 */     throw JsonMappingException.wrapWithPath(t, bean, index);
/*     */   }
/*     */   
/*     */ 
/*     */   @Deprecated
/*     */   public void wrapAndThrow(Throwable t, Object bean, String fieldName)
/*     */     throws IOException
/*     */   {
/* 165 */     wrapAndThrow(null, t, bean, fieldName);
/*     */   }
/*     */   
/*     */ 
/*     */   @Deprecated
/*     */   public void wrapAndThrow(Throwable t, Object bean, int index)
/*     */     throws IOException
/*     */   {
/* 173 */     wrapAndThrow(null, t, bean, index);
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\codehaus\jackson\map\ser\SerializerBase.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */