/*     */ package com.netapp.asup.data.function.aggregation;
/*     */ 
/*     */ import java.util.HashMap;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ public enum AggregationType
/*     */ {
/*  10 */   COUNT("count", new SimpleNumberObjectAggregation(null), new NumberAggregationFunction()), 
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  17 */   MIN("min", new ReverseNumberObjectAggregation(null), new NumberAggregationFunction()), 
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  30 */   CONCAT("concat", new StringObjectAggregation(null), new InstanceAggregationFunction()), 
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  37 */   MAX("max", new SimpleNumberObjectAggregation(null), new NumberAggregationFunction()), 
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  49 */   AVERAGE("average", new AverageObjectAggregation(null), new AverageAggregationFunction()), 
/*  50 */   SUM("sum", new SimpleNumberObjectAggregation(null), new NumberAggregationFunction());
/*     */   
/*     */ 
/*     */ 
/*     */   private final String name;
/*     */   
/*     */   private static Map<String, AggregationType> aggregationTypeMap;
/*     */   
/*     */   private final InstanceAggregationFunction<?> instanceAggregationFunction;
/*     */   
/*     */   private final ObjectAggregationFunction<?> objectAggregationFunction;
/*     */   
/*     */ 
/*     */   private AggregationType(String name, ObjectAggregationFunction<?> objectAggregationFunction, InstanceAggregationFunction<?> instanceAggregationFunction)
/*     */   {
/*  65 */     this.name = name;
/*  66 */     this.instanceAggregationFunction = instanceAggregationFunction;
/*  67 */     this.objectAggregationFunction = objectAggregationFunction;
/*     */   }
/*     */   
/*     */   static {
/*  71 */     populateAggregationTypeMap();
/*     */   }
/*     */   
/*     */   private static void populateAggregationTypeMap() {
/*  75 */     aggregationTypeMap = new HashMap();
/*  76 */     for (AggregationType type : values()) {
/*  77 */       aggregationTypeMap.put(type.getName(), type);
/*     */     }
/*     */   }
/*     */   
/*     */   public static AggregationType getAggregationType(String name) {
/*  82 */     return (AggregationType)aggregationTypeMap.get(name);
/*     */   }
/*     */   
/*     */   public static abstract interface InstanceAggregationFunction<T>
/*     */   {
/*     */     public abstract T compute(T paramT, String paramString);
/*     */   }
/*     */   
/*     */   private static abstract interface NumberAggregationFunction extends AggregationType.InstanceAggregationFunction<Double>
/*     */   {}
/*     */   
/*     */   public static class AverageAggregationFunction implements AggregationType.InstanceAggregationFunction<Map<String, Double>>
/*     */   {
/*     */     public Map<String, Double> compute(Map<String, Double> result, String value) {
/*  96 */       result.put("sum", (Double)AggregationType.SUM.getInstanceAggregationFunction().compute(result.get("sum"), value));
/*  97 */       result.put("count", (Double)AggregationType.COUNT.getInstanceAggregationFunction().compute(result.get("count"), value));
/*  98 */       return result;
/*     */     }
/*     */   }
/*     */   
/*     */   public static abstract interface ObjectAggregationFunction<T>
/*     */   {
/*     */     public abstract String compute(T paramT);
/*     */     
/*     */     public abstract T initializeResult();
/*     */   }
/*     */   
/*     */   private static class ReverseNumberObjectAggregation implements AggregationType.ObjectAggregationFunction<Double>
/*     */   {
/*     */     public String compute(Double result) {
/* 112 */       return result.toString();
/*     */     }
/*     */     
/*     */     public Double initializeResult() {
/* 116 */       return Double.valueOf(Double.MAX_VALUE);
/*     */     }
/*     */   }
/*     */   
/*     */   private static class SimpleNumberObjectAggregation implements AggregationType.ObjectAggregationFunction<Double>
/*     */   {
/*     */     public String compute(Double result)
/*     */     {
/* 124 */       return result.toString();
/*     */     }
/*     */     
/*     */     public Double initializeResult() {
/* 128 */       return new Double(0.0D);
/*     */     }
/*     */   }
/*     */   
/*     */   private static class StringObjectAggregation implements AggregationType.ObjectAggregationFunction<String>
/*     */   {
/*     */     public String compute(String result)
/*     */     {
/* 136 */       return result.toString();
/*     */     }
/*     */     
/*     */     public String initializeResult()
/*     */     {
/* 141 */       return "";
/*     */     }
/*     */   }
/*     */   
/*     */   private static class AverageObjectAggregation implements AggregationType.ObjectAggregationFunction<Map<String, Double>>
/*     */   {
/*     */     public String compute(Map<String, Double> result)
/*     */     {
/* 149 */       if (((Double)result.get("count")).doubleValue() != 0.0D) {
/* 150 */         return Double.valueOf(((Double)result.get("sum")).doubleValue() / ((Double)result.get("count")).doubleValue()).toString();
/*     */       }
/* 152 */       return "";
/*     */     }
/*     */     
/*     */     public Map<String, Double> initializeResult()
/*     */     {
/* 157 */       Map<String, Double> map = new HashMap();
/* 158 */       map.put("sum", Double.valueOf("0"));
/* 159 */       map.put("count", Double.valueOf("0"));
/* 160 */       return map;
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public <T> InstanceAggregationFunction<T> getInstanceAggregationFunction()
/*     */   {
/* 168 */     return this.instanceAggregationFunction;
/*     */   }
/*     */   
/*     */ 
/*     */   public <T> ObjectAggregationFunction<T> getObjectAggregationFunction()
/*     */   {
/* 174 */     return this.objectAggregationFunction;
/*     */   }
/*     */   
/*     */   public String getName() {
/* 178 */     return this.name;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asup\data\function\aggregation\AggregationType.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */