package prefuse.action.layout;

import java.awt.geom.Rectangle2D;
import java.util.Iterator;
import prefuse.Visualization;
import prefuse.data.Table;
import prefuse.data.column.ColumnMetadata;
import prefuse.data.expression.Predicate;
import prefuse.data.query.NumberRangeModel;
import prefuse.data.query.ObjectRangeModel;
import prefuse.data.tuple.TupleSet;
import prefuse.util.MathLib;
import prefuse.util.ui.ValuedRangeModel;
import prefuse.visual.VisualItem;

public class AxisLayout
  extends Layout
{
  private String m_field;
  private int m_scale = 0;
  private int m_axis = 0;
  private int m_type = -1;
  private boolean m_modelSet = false;
  private ValuedRangeModel m_model = null;
  private Predicate m_filter = null;
  private double m_min;
  private double m_range;
  private double[] m_dist = new double[2];
  
  public AxisLayout(String paramString1, String paramString2)
  {
    super(paramString1);
    this.m_field = paramString2;
  }
  
  public AxisLayout(String paramString1, String paramString2, int paramInt)
  {
    this(paramString1, paramString2);
    setAxis(paramInt);
  }
  
  public AxisLayout(String paramString1, String paramString2, int paramInt, Predicate paramPredicate)
  {
    this(paramString1, paramString2, paramInt);
    setFilter(paramPredicate);
  }
  
  public void setRangeModel(ValuedRangeModel paramValuedRangeModel)
  {
    this.m_model = paramValuedRangeModel;
    this.m_modelSet = (paramValuedRangeModel != null);
  }
  
  public ValuedRangeModel getRangeModel()
  {
    return this.m_model;
  }
  
  public void setFilter(Predicate paramPredicate)
  {
    this.m_filter = paramPredicate;
  }
  
  public int getScale()
  {
    return this.m_scale;
  }
  
  public void setScale(int paramInt)
  {
    if ((paramInt < 0) || (paramInt >= 4)) {
      throw new IllegalArgumentException("Unrecognized scale value: " + paramInt);
    }
    this.m_scale = paramInt;
  }
  
  public int getAxis()
  {
    return this.m_axis;
  }
  
  public void setAxis(int paramInt)
  {
    if ((paramInt < 0) || (paramInt >= 2)) {
      throw new IllegalArgumentException("Unrecognized axis value: " + paramInt);
    }
    this.m_axis = paramInt;
  }
  
  public int getDataType()
  {
    return this.m_type;
  }
  
  public void setDataType(int paramInt)
  {
    if ((paramInt < 0) || (paramInt >= 3)) {
      throw new IllegalArgumentException("Unrecognized data type value: " + paramInt);
    }
    this.m_type = paramInt;
  }
  
  public void run(double paramDouble)
  {
    TupleSet localTupleSet = this.m_vis.getGroup(this.m_group);
    if (!(localTupleSet instanceof Table)) {
      throw new IllegalStateException();
    }
    setMinMax();
    Table localTable = (Table)localTupleSet;
    switch (getDataType(localTable))
    {
    case 2: 
      numericalLayout(localTable);
      break;
    default: 
      ordinalLayout(localTable);
    }
  }
  
  protected int getDataType(Table paramTable)
  {
    if (this.m_type == -1)
    {
      if (paramTable.canGetDouble(this.m_field)) {
        return 2;
      }
      return 1;
    }
    return this.m_type;
  }
  
  protected void setMinMax()
  {
    Rectangle2D localRectangle2D = getLayoutBounds();
    if (this.m_axis == 0)
    {
      this.m_min = localRectangle2D.getMinX();
      this.m_range = (localRectangle2D.getMaxX() - this.m_min);
    }
    else
    {
      this.m_min = localRectangle2D.getMaxY();
      this.m_range = (localRectangle2D.getMinY() - this.m_min);
    }
  }
  
  protected void set(VisualItem paramVisualItem, double paramDouble)
  {
    double d = this.m_min + paramDouble * this.m_range;
    if (this.m_axis == 0) {
      setX(paramVisualItem, null, d);
    } else {
      setY(paramVisualItem, null, d);
    }
  }
  
  protected void numericalLayout(Table paramTable)
  {
    if (!this.m_modelSet)
    {
      localObject = paramTable.getMetadata(this.m_field);
      this.m_dist[0] = paramTable.getDouble(((ColumnMetadata)localObject).getMinimumRow(), this.m_field);
      this.m_dist[1] = paramTable.getDouble(((ColumnMetadata)localObject).getMaximumRow(), this.m_field);
      double d1 = this.m_dist[0];
      double d3 = this.m_dist[1];
      if (this.m_model == null) {
        this.m_model = new NumberRangeModel(d1, d3, d1, d3);
      } else {
        ((NumberRangeModel)this.m_model).setValueRange(d1, d3, d1, d3);
      }
    }
    else
    {
      this.m_dist[0] = ((Number)this.m_model.getLowValue()).doubleValue();
      this.m_dist[1] = ((Number)this.m_model.getHighValue()).doubleValue();
    }
    Object localObject = this.m_vis.items(this.m_group, this.m_filter);
    while (((Iterator)localObject).hasNext())
    {
      VisualItem localVisualItem = (VisualItem)((Iterator)localObject).next();
      double d2 = localVisualItem.getDouble(this.m_field);
      double d4 = MathLib.interp(this.m_scale, d2, this.m_dist);
      set(localVisualItem, d4);
    }
  }
  
  protected void ordinalLayout(Table paramTable)
  {
    if (!this.m_modelSet)
    {
      localObject = paramTable.getMetadata(this.m_field);
      Object[] arrayOfObject = ((ColumnMetadata)localObject).getOrdinalArray();
      if (this.m_model == null) {
        this.m_model = new ObjectRangeModel(arrayOfObject);
      } else {
        ((ObjectRangeModel)this.m_model).setValueRange(arrayOfObject);
      }
    }
    Object localObject = (ObjectRangeModel)this.m_model;
    int i = ((ObjectRangeModel)localObject).getValue();
    int j = i + ((ObjectRangeModel)localObject).getExtent();
    double d = j - i;
    Iterator localIterator = this.m_vis.items(this.m_group, this.m_filter);
    while (localIterator.hasNext())
    {
      VisualItem localVisualItem = (VisualItem)localIterator.next();
      int k = ((ObjectRangeModel)localObject).getIndex(localVisualItem.get(this.m_field)) - i;
      set(localVisualItem, k / d);
    }
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\action\layout\AxisLayout.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */