package prefuse.data;

import java.util.HashMap;
import prefuse.util.PrefuseLib;

public class Schema
  implements Cloneable
{
  private String[] m_names;
  private Class[] m_types;
  private Object[] m_dflts;
  private HashMap m_lookup;
  private int m_size;
  private boolean m_locked;
  
  public Schema()
  {
    this(10);
  }
  
  public Schema(int paramInt)
  {
    this.m_names = new String[paramInt];
    this.m_types = new Class[paramInt];
    this.m_dflts = new Object[paramInt];
    this.m_size = 0;
    this.m_locked = false;
  }
  
  public Schema(String[] paramArrayOfString, Class[] paramArrayOfClass)
  {
    this(paramArrayOfString.length);
    if (paramArrayOfString.length != paramArrayOfClass.length) {
      throw new IllegalArgumentException("Input arrays should be the same length");
    }
    for (int i = 0; i < paramArrayOfString.length; i++) {
      addColumn(paramArrayOfString[i], paramArrayOfClass[i], null);
    }
  }
  
  public Schema(String[] paramArrayOfString, Class[] paramArrayOfClass, Object[] paramArrayOfObject)
  {
    this(paramArrayOfString.length);
    if ((paramArrayOfString.length != paramArrayOfClass.length) || (paramArrayOfClass.length != paramArrayOfObject.length)) {
      throw new IllegalArgumentException("Input arrays should be the same length");
    }
    for (int i = 0; i < paramArrayOfString.length; i++) {
      addColumn(paramArrayOfString[i], paramArrayOfClass[i], paramArrayOfObject[i]);
    }
  }
  
  public Object clone()
  {
    return new Schema(this.m_names, this.m_types, this.m_dflts);
  }
  
  protected void initLookup()
  {
    this.m_lookup = new HashMap();
    for (int i = 0; i < this.m_names.length; i++) {
      this.m_lookup.put(this.m_names[i], new Integer(i));
    }
  }
  
  public Schema lockSchema()
  {
    this.m_locked = true;
    return this;
  }
  
  public boolean isLocked()
  {
    return this.m_locked;
  }
  
  public void addColumn(String paramString, Class paramClass)
  {
    addColumn(paramString, paramClass, null);
  }
  
  public void addColumn(String paramString, Class paramClass, Object paramObject)
  {
    if (this.m_locked) {
      throw new IllegalStateException("Can not add column to a locked Schema.");
    }
    if (paramString == null) {
      throw new IllegalArgumentException("Null column names are not allowed.");
    }
    if (paramClass == null) {
      throw new IllegalArgumentException("Null column types are not allowed.");
    }
    for (int i = 0; i < this.m_size; i++) {
      if (this.m_names[i].equals(paramString)) {
        throw new IllegalArgumentException("Duplicate column names are not allowed: " + this.m_names[i]);
      }
    }
    if (this.m_names.length == this.m_size)
    {
      i = 3 * this.m_names.length / 2 + 1;
      String[] arrayOfString = new String[i];
      Class[] arrayOfClass = new Class[i];
      Object[] arrayOfObject = new Object[i];
      System.arraycopy(this.m_names, 0, arrayOfString, 0, this.m_size);
      System.arraycopy(this.m_types, 0, arrayOfClass, 0, this.m_size);
      System.arraycopy(this.m_dflts, 0, arrayOfObject, 0, this.m_size);
      this.m_names = arrayOfString;
      this.m_types = arrayOfClass;
      this.m_dflts = arrayOfObject;
    }
    this.m_names[this.m_size] = paramString;
    this.m_types[this.m_size] = paramClass;
    this.m_dflts[this.m_size] = paramObject;
    if (this.m_lookup != null) {
      this.m_lookup.put(paramString, new Integer(this.m_size));
    }
    this.m_size += 1;
  }
  
  public void addInterpolatedColumn(String paramString, Class paramClass, Object paramObject)
  {
    addColumn(paramString, paramClass, paramObject);
    addColumn(PrefuseLib.getStartField(paramString), paramClass, paramObject);
    addColumn(PrefuseLib.getEndField(paramString), paramClass, paramObject);
  }
  
  public void addInterpolatedColumn(String paramString, Class paramClass)
  {
    addInterpolatedColumn(paramString, paramClass, null);
  }
  
  public int getColumnCount()
  {
    return this.m_size;
  }
  
  public String getColumnName(int paramInt)
  {
    return this.m_names[paramInt];
  }
  
  public int getColumnIndex(String paramString)
  {
    if (this.m_lookup == null) {
      initLookup();
    }
    Integer localInteger = (Integer)this.m_lookup.get(paramString);
    return localInteger == null ? -1 : localInteger.intValue();
  }
  
  public Class getColumnType(int paramInt)
  {
    return this.m_types[paramInt];
  }
  
  public Class getColumnType(String paramString)
  {
    int i = getColumnIndex(paramString);
    return i < 0 ? null : this.m_types[i];
  }
  
  public Object getDefault(int paramInt)
  {
    return this.m_dflts[paramInt];
  }
  
  public Object getDefault(String paramString)
  {
    int i = getColumnIndex(paramString);
    return i < 0 ? null : this.m_dflts[i];
  }
  
  public void setDefault(int paramInt, Object paramObject)
  {
    if (this.m_locked) {
      throw new IllegalStateException("Can not update default values of a locked Schema.");
    }
    this.m_dflts[paramInt] = paramObject;
  }
  
  public void setDefault(String paramString, Object paramObject)
  {
    if (this.m_locked) {
      throw new IllegalStateException("Can not update default values of a locked Schema.");
    }
    int i = getColumnIndex(paramString);
    this.m_dflts[i] = paramObject;
  }
  
  public void setDefault(String paramString, int paramInt)
  {
    setDefault(paramString, new Integer(paramInt));
  }
  
  public void setDefault(String paramString, long paramLong)
  {
    setDefault(paramString, new Long(paramLong));
  }
  
  public void setDefault(String paramString, float paramFloat)
  {
    setDefault(paramString, new Float(paramFloat));
  }
  
  public void setDefault(String paramString, double paramDouble)
  {
    setDefault(paramString, new Double(paramDouble));
  }
  
  public void setDefault(String paramString, boolean paramBoolean)
  {
    setDefault(paramString, paramBoolean ? Boolean.TRUE : Boolean.FALSE);
  }
  
  public void setInterpolatedDefault(String paramString, Object paramObject)
  {
    setDefault(paramString, paramObject);
    setDefault(PrefuseLib.getStartField(paramString), paramObject);
    setDefault(PrefuseLib.getEndField(paramString), paramObject);
  }
  
  public void setInterpolatedDefault(String paramString, int paramInt)
  {
    setInterpolatedDefault(paramString, new Integer(paramInt));
  }
  
  public void setInterpolatedDefault(String paramString, long paramLong)
  {
    setInterpolatedDefault(paramString, new Long(paramLong));
  }
  
  public void setInterpolatedDefault(String paramString, float paramFloat)
  {
    setInterpolatedDefault(paramString, new Float(paramFloat));
  }
  
  public void setInterpolatedDefault(String paramString, double paramDouble)
  {
    setInterpolatedDefault(paramString, new Double(paramDouble));
  }
  
  public void setInterpolatedDefault(String paramString, boolean paramBoolean)
  {
    setInterpolatedDefault(paramString, paramBoolean ? Boolean.TRUE : Boolean.FALSE);
  }
  
  public boolean equals(Object paramObject)
  {
    if (!(paramObject instanceof Schema)) {
      return false;
    }
    Schema localSchema = (Schema)paramObject;
    if (this.m_size != localSchema.getColumnCount()) {
      return false;
    }
    for (int i = 0; i < this.m_size; i++) {
      if ((!this.m_names[i].equals(localSchema.getColumnName(i))) || (!this.m_types[i].equals(localSchema.getColumnType(i))) || (!this.m_dflts[i].equals(localSchema.getDefault(i)))) {
        return false;
      }
    }
    return true;
  }
  
  public boolean isAssignableFrom(Schema paramSchema)
  {
    int i = paramSchema.getColumnCount();
    if (i > this.m_size) {
      return false;
    }
    for (int j = 0; j < i; j++)
    {
      int k = getColumnIndex(paramSchema.getColumnName(j));
      if (k < 0) {
        return false;
      }
      if (!this.m_types[k].equals(paramSchema.getColumnType(j))) {
        return false;
      }
    }
    return true;
  }
  
  public int hashCode()
  {
    int i = 0;
    for (int j = 0; j < this.m_size; j++)
    {
      int k = j + 1;
      int m = k * this.m_names[j].hashCode();
      m ^= k * this.m_types[j].hashCode();
      if (this.m_dflts[j] != null) {
        m ^= this.m_dflts[j].hashCode();
      }
      i ^= m;
    }
    return i;
  }
  
  public String toString()
  {
    StringBuffer localStringBuffer = new StringBuffer();
    localStringBuffer.append("Schema[");
    for (int i = 0; i < this.m_size; i++)
    {
      if (i > 0) {
        localStringBuffer.append(' ');
      }
      localStringBuffer.append('(').append(this.m_names[i]).append(", ");
      localStringBuffer.append(this.m_types[i].getName()).append(", ");
      localStringBuffer.append(this.m_dflts[i]).append(')');
    }
    localStringBuffer.append(']');
    return localStringBuffer.toString();
  }
  
  public Table instantiate()
  {
    return instantiate(0);
  }
  
  public Table instantiate(int paramInt)
  {
    Table localTable = new Table(paramInt, this.m_size);
    for (int i = 0; i < this.m_size; i++) {
      localTable.addColumn(this.m_names[i], this.m_types[i], this.m_dflts[i]);
    }
    return localTable;
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\data\Schema.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */