package prefuse.data.io.sql;

import java.math.BigDecimal;
import java.sql.Array;
import java.sql.Blob;
import java.sql.Clob;
import java.sql.Date;
import java.sql.Ref;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.Time;
import java.sql.Timestamp;
import prefuse.data.Table;

public class DefaultSQLDataHandler
  implements SQLDataHandler
{
  private boolean m_ignoreUnknownTypes;
  
  public DefaultSQLDataHandler()
  {
    this(true);
  }
  
  public DefaultSQLDataHandler(boolean paramBoolean)
  {
    this.m_ignoreUnknownTypes = paramBoolean;
  }
  
  public void setIgnoreUnknownTypes(boolean paramBoolean)
  {
    this.m_ignoreUnknownTypes = paramBoolean;
  }
  
  public boolean isIgnoreUnknownTypes()
  {
    return this.m_ignoreUnknownTypes;
  }
  
  public void process(Table paramTable, int paramInt1, ResultSet paramResultSet, int paramInt2)
    throws SQLException
  {
    ResultSetMetaData localResultSetMetaData = paramResultSet.getMetaData();
    String str = localResultSetMetaData.getColumnName(paramInt2);
    int i = localResultSetMetaData.getColumnType(paramInt2);
    switch (i)
    {
    case 2003: 
      paramTable.set(paramInt1, str, paramResultSet.getArray(paramInt2));
      break;
    case -5: 
      paramTable.setLong(paramInt1, str, paramResultSet.getLong(paramInt2));
      break;
    case -4: 
    case -3: 
    case -2: 
      paramTable.set(paramInt1, str, paramResultSet.getBytes(paramInt2));
      break;
    case -7: 
    case 16: 
      paramTable.setBoolean(paramInt1, str, paramResultSet.getBoolean(paramInt2));
      break;
    case 2004: 
      paramTable.set(paramInt1, str, paramResultSet.getBlob(paramInt2));
      break;
    case -1: 
    case 1: 
    case 12: 
      paramTable.setString(paramInt1, str, paramResultSet.getString(paramInt2));
      break;
    case 2005: 
      paramTable.set(paramInt1, str, paramResultSet.getClob(paramInt2));
      break;
    case 91: 
      paramTable.setDate(paramInt1, str, paramResultSet.getDate(paramInt2));
      break;
    case 2: 
    case 3: 
    case 6: 
    case 8: 
      paramTable.setDouble(paramInt1, str, paramResultSet.getDouble(paramInt2));
      break;
    case -6: 
    case 4: 
    case 5: 
      paramTable.setInt(paramInt1, str, paramResultSet.getInt(paramInt2));
      break;
    case 2000: 
      paramTable.set(paramInt1, str, paramResultSet.getObject(paramInt2));
      break;
    case 7: 
      paramTable.setFloat(paramInt1, str, paramResultSet.getFloat(paramInt2));
      break;
    case 2006: 
      paramTable.set(paramInt1, str, paramResultSet.getRef(paramInt2));
      break;
    case 92: 
      paramTable.setDate(paramInt1, str, paramResultSet.getTime(paramInt2));
      break;
    case 93: 
      paramTable.setDate(paramInt1, str, paramResultSet.getTimestamp(paramInt2));
      break;
    case 0: 
    case 70: 
    case 1111: 
    case 2001: 
    case 2002: 
    default: 
      if (!this.m_ignoreUnknownTypes) {
        paramTable.set(paramInt1, str, paramResultSet.getObject(paramInt2));
      }
      break;
    }
  }
  
  public Class getDataType(String paramString, int paramInt)
  {
    switch (paramInt)
    {
    case 2003: 
      return Array.class;
    case -5: 
      return Long.TYPE;
    case -4: 
    case -3: 
    case -2: 
      return byte[].class;
    case -7: 
    case 16: 
      return Boolean.TYPE;
    case 2004: 
      return Blob.class;
    case -1: 
    case 1: 
    case 12: 
      return String.class;
    case 2005: 
      return Clob.class;
    case 91: 
      return Date.class;
    case 2: 
    case 3: 
      return BigDecimal.class;
    case 6: 
    case 8: 
      return Double.TYPE;
    case -6: 
    case 4: 
    case 5: 
      return Integer.TYPE;
    case 2000: 
      return Object.class;
    case 7: 
      return Float.TYPE;
    case 2006: 
      return Ref.class;
    case 92: 
      return Time.class;
    case 93: 
      return Timestamp.class;
    }
    if (!this.m_ignoreUnknownTypes) {
      return Object.class;
    }
    return null;
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\data\io\sql\DefaultSQLDataHandler.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */