package prefuse.data.search;

import java.util.Iterator;
import java.util.StringTokenizer;
import prefuse.data.Tuple;

public class PrefixSearchTupleSet
  extends SearchTupleSet
{
  private Trie m_trie;
  private Trie.TrieNode m_curNode;
  private String m_delim = " \t\n\r";
  private String m_query = "";
  
  public PrefixSearchTupleSet()
  {
    this(false);
  }
  
  public PrefixSearchTupleSet(boolean paramBoolean)
  {
    this.m_trie = new Trie(paramBoolean);
  }
  
  public String getDelimiterString()
  {
    return this.m_delim;
  }
  
  public void setDelimiterString(String paramString)
  {
    this.m_delim = paramString;
  }
  
  public String getQuery()
  {
    return this.m_query;
  }
  
  public void search(String paramString)
  {
    if (paramString == null) {
      paramString = "";
    }
    if (paramString.equals(this.m_query)) {
      return;
    }
    Tuple[] arrayOfTuple1 = clearInternal();
    this.m_query = paramString;
    StringTokenizer localStringTokenizer = new StringTokenizer(this.m_query, this.m_delim);
    if (!localStringTokenizer.hasMoreTokens()) {
      this.m_query = "";
    }
    while (localStringTokenizer.hasMoreTokens()) {
      prefixSearch(localStringTokenizer.nextToken());
    }
    Tuple[] arrayOfTuple2 = getTupleCount() > 0 ? toArray() : null;
    fireTupleEvent(arrayOfTuple2, arrayOfTuple1);
  }
  
  private void prefixSearch(String paramString)
  {
    this.m_curNode = this.m_trie.find(paramString);
    if (this.m_curNode != null)
    {
      Iterator localIterator = trieIterator();
      while (localIterator.hasNext()) {
        addInternal((Tuple)localIterator.next());
      }
    }
  }
  
  public void index(Tuple paramTuple, String paramString)
  {
    String str1;
    if ((str1 = paramTuple.getString(paramString)) == null) {
      return;
    }
    StringTokenizer localStringTokenizer = new StringTokenizer(str1, this.m_delim);
    while (localStringTokenizer.hasMoreTokens())
    {
      String str2 = localStringTokenizer.nextToken();
      addString(str2, paramTuple);
    }
  }
  
  private void addString(String paramString, Tuple paramTuple)
  {
    this.m_trie.addString(paramString, paramTuple);
  }
  
  public boolean isUnindexSupported()
  {
    return true;
  }
  
  public void unindex(Tuple paramTuple, String paramString)
  {
    String str1;
    if ((str1 = paramTuple.getString(paramString)) == null) {
      return;
    }
    StringTokenizer localStringTokenizer = new StringTokenizer(str1, this.m_delim);
    while (localStringTokenizer.hasMoreTokens())
    {
      String str2 = localStringTokenizer.nextToken();
      removeString(str2, paramTuple);
    }
  }
  
  private void removeString(String paramString, Tuple paramTuple)
  {
    this.m_trie.removeString(paramString, paramTuple);
  }
  
  private Iterator trieIterator()
  {
    Trie tmp8_5 = this.m_trie;
    tmp8_5.getClass();
    return new Trie.TrieIterator(tmp8_5, this.m_curNode);
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\data\search\PrefixSearchTupleSet.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */